/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：信息导入记录表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.domain;

import java.io.Serializable;

import com.xwd.hospital.server.rest.res.ApiCode;
import lombok.*;
import java.util.List;

import com.baomidou.mybatisplus.annotation.*;

import io.swagger.v3.oas.annotations.media.Schema;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonProperty;

import com.xwd.hospital.server.base.BaseDomain;
import com.xwd.hospital.server.enums.YesNoEnum;

@Data
@Builder(builderMethodName = "newBuilder")
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@TableName("`pms_excel_import_info`")
@Schema(name = "ExcelImportInfo", description = "信息导入记录表")
public class ExcelImportInfo extends BaseDomain {
    /**
     * Id
     */
    @TableId(value = "id", type = IdType.AUTO)
    @Schema(description = "Id", nullable = false)
    private Long id;
    /**
     * 文件名称
     */
    @TableField(value = "file_name")
    @Schema(description = "文件名称", nullable = false)
    private String fileName;
    /**
     * 导入数据类型
     */
    @TableField(value = "import_type")
    @Schema(description = "导入数据类型", nullable = false)
    private String importType;
    /**
     * 导入状态
     */
    @TableField(value = "import_state")
    @Schema(description = "导入状态", nullable = false)
    private YesNoEnum importState;
    /**
     * 失败原因
     */
    @TableField(value = "fail_reason")
    @Schema(description = "失败原因")
    private String failReason;
    /**
     * 错误所在行数
     */
    @TableField(value = "fail_row")
    @Schema(description = "错误所在行数")
    private Long failRow;
    /**
     * 导入时间
     */
    @TableField(value = "import_time")
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "导入时间", nullable = false)
    private java.util.Date importTime;
    /**
     * 操作人Id
     */
    @TableField(value = "editor_id")
    @Schema(description = "操作人Id", nullable = false)
    private Long editorId;
    /**
     * 操作人
     */
    @TableField(value = "editor_name")
    @Schema(description = "操作人", nullable = false)
    private String editorName;
    /**
     * 创建时间
     */
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间", nullable = false)
    private java.util.Date createTime;
    /**
     * 更新时间
     */
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间", nullable = false)
    private java.util.Date updateTime;

    /**
     * 设置默认值
     */
    @Override
    public ExcelImportInfo setDefault() {
        if (this.getImportState() == null) {
            this.setImportState(YesNoEnum.NO);
        }
        if (this.getImportTime() == null) {
            this.setImportTime(new java.util.Date());
        }
        if (this.getEditorId() == null) {
            this.setEditorId(1L);
        }
        if (this.getEditorName() == null) {
            this.setEditorName("admin");
        }
        if (this.getCreateTime() == null) {
            this.setCreateTime(new java.util.Date());
        }
        if (this.getUpdateTime() == null) {
            this.setUpdateTime(new java.util.Date());
        }
        return this;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate(boolean throwException) {
        if (this.getFileName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "文件名称不能为空！");
            }
            return false;
        }
        if (this.getImportType() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "导入数据类型不能为空！");
            }
            return false;
        }
        if (this.getImportState() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "导入状态不能为空！");
            }
            return false;
        }
        if (this.getImportTime() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "导入时间不能为空！");
            }
            return false;
        }
        if (this.getEditorId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人Id不能为空！");
            }
            return false;
        }
        if (this.getEditorName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人不能为空！");
            }
            return false;
        }
        return true;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate() {
        return this.validate(false);
    }

}
