/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：信息导入详情表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.domain;

import java.io.Serializable;

import com.xwd.hospital.server.rest.res.ApiCode;
import lombok.*;
import java.util.List;

import com.baomidou.mybatisplus.annotation.*;

import io.swagger.v3.oas.annotations.media.Schema;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonProperty;

import com.xwd.hospital.server.base.BaseDomain;
import com.xwd.hospital.server.domain.ExcelImportInfo;

@Data
@Builder(builderMethodName = "newBuilder")
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@TableName("`pms_excel_import_info_detail`")
@Schema(name = "ExcelImportInfoDetail", description = "信息导入详情表")
public class ExcelImportInfoDetail extends BaseDomain {
    /**
     * Id
     */
    @TableId(value = "id", type = IdType.AUTO)
    @Schema(description = "Id", nullable = false)
    private Long id;
    /**
     * 导入记录Id
     */
    @TableField(value = "import_id")
    @Schema(description = "导入记录Id", nullable = false)
    private Long importId;
    /**
     * 导入记录Id
     */
    @Schema(description = "导入记录")
    @TableField(exist = false)
    private ExcelImportInfo importInfo;
    /**
     * 姓名
     */
    @TableField(value = "name")
    @Schema(description = "姓名")
    private String name;
    /**
     * 性别
     */
    @TableField(value = "sex")
    @Schema(description = "性别")
    private String sex;
    /**
     * 年龄
     */
    @TableField(value = "age")
    @Schema(description = "年龄")
    private String age;
    /**
     * 手机号
     */
    @TableField(value = "phone")
    @Schema(description = "手机号")
    private String phone;
    /**
     * 证件号
     */
    @TableField(value = "id_no")
    @Schema(description = "证件号")
    private String idNo;
    /**
     * 省
     */
    @TableField(value = "province")
    @Schema(description = "省")
    private String province;
    /**
     * 市
     */
    @TableField(value = "city")
    @Schema(description = "市")
    private String city;
    /**
     * 区
     */
    @TableField(value = "district")
    @Schema(description = "区")
    private String district;
    /**
     * 详细地址
     */
    @TableField(value = "address_detail")
    @Schema(description = "详细地址")
    private String addressDetail;
    /**
     * 既往病史
     */
    @TableField(value = "anamnesis")
    @Schema(description = "既往病史")
    private String anamnesis;
    /**
     * 药物过敏史
     */
    @TableField(value = "drug_allergy_history")
    @Schema(description = "药物过敏史")
    private String drugAllergyHistory;
    /**
     * 处方时间
     */
    @TableField(value = "prescription_time")
    @Schema(description = "处方时间")
    private String prescriptionTime;
    /**
     * 处方医院
     */
    @TableField(value = "prescription_hospital")
    @Schema(description = "处方医院")
    private String prescriptionHospital;
    /**
     * 处方科室
     */
    @TableField(value = "prescription_departemnt")
    @Schema(description = "处方科室")
    private String prescriptionDepartemnt;
    /**
     * 处方医生
     */
    @TableField(value = "prescription_doctor")
    @Schema(description = "处方医生")
    private String prescriptionDoctor;
    /**
     * 处方结果
     */
    @TableField(value = "prescription_result")
    @Schema(description = "处方结果")
    private String prescriptionResult;
    /**
     * 报告项目
     */
    @TableField(value = "report_item")
    @Schema(description = "报告项目")
    private String reportItem;
    /**
     * 报告描述
     */
    @TableField(value = "report_desc", select = false)
    @Schema(description = "报告描述")
    private String reportDesc;
    /**
     * 报告时间
     */
    @TableField(value = "report_time")
    @Schema(description = "报告时间")
    private String reportTime;
    /**
     * 报告医院
     */
    @TableField(value = "report_hospital")
    @Schema(description = "报告医院")
    private String reportHospital;
    /**
     * 报告医生
     */
    @TableField(value = "report_doctor")
    @Schema(description = "报告医生")
    private String reportDoctor;
    /**
     * 医生医嘱
     */
    @TableField(value = "doctor_ask")
    @Schema(description = "医生医嘱")
    private String doctorAsk;
    /**
     * 操作人Id
     */
    @TableField(value = "editor_id")
    @Schema(description = "操作人Id", nullable = false)
    private Long editorId;
    /**
     * 操作人
     */
    @TableField(value = "editor_name")
    @Schema(description = "操作人", nullable = false)
    private String editorName;
    /**
     * 创建时间
     */
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "创建时间", nullable = false)
    private java.util.Date createTime;
    /**
     * 更新时间
     */
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Schema(description = "更新时间", nullable = false)
    private java.util.Date updateTime;

    /**
     * 设置默认值
     */
    @Override
    public ExcelImportInfoDetail setDefault() {
        if (this.getEditorId() == null) {
            this.setEditorId(1L);
        }
        if (this.getEditorName() == null) {
            this.setEditorName("admin");
        }
        if (this.getCreateTime() == null) {
            this.setCreateTime(new java.util.Date());
        }
        if (this.getUpdateTime() == null) {
            this.setUpdateTime(new java.util.Date());
        }
        return this;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate(boolean throwException) {
        if (this.getImportId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "导入记录Id不能为空！");
            }
            return false;
        }
        if (this.getEditorId() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人Id不能为空！");
            }
            return false;
        }
        if (this.getEditorName() == null) {
            if (throwException) {
                throw new ApiCode.ApiException(-1, "操作人不能为空！");
            }
            return false;
        }
        return true;
    }

    /**
     * 数据验证
     */
    @Override
    public boolean validate() {
        return this.validate(false);
    }

}
