/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：家庭医生地址关系表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest;

import java.util.List;
import java.util.Arrays;

import cn.dev33.satoken.stp.SaLoginModel;
import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.google.gson.JsonObject;
import com.xwd.hospital.server.annotation.ApiCommon;
import com.xwd.hospital.server.annotation.AuthUser;
import com.xwd.hospital.server.base.BaseController;
import com.xwd.hospital.server.domain.ReferralRecord;
import com.xwd.hospital.server.domain.User;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.domain.DoctorFamilyAddressInfo;
import com.xwd.hospital.server.rest.req.DoctorFamilyAddressInfoParam;
import com.xwd.hospital.server.rest.res.ApiResponse;
import com.xwd.hospital.server.rest.thirdPartReq.BindNumberReq;
import com.xwd.hospital.server.service.CallApiService;
import com.xwd.hospital.server.service.DoctorFamilyAddressInfoService;
import com.xwd.hospital.server.service.MapApiService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import okhttp3.OkHttpClient;
import org.apache.commons.lang3.StringUtils;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import retrofit2.Call;
import retrofit2.Response;
import retrofit2.Retrofit;
import retrofit2.converter.gson.GsonConverterFactory;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@Tag(name = "DoctorFamilyAddressInfoController", description = "家庭医生地址关系表管理")
@RequestMapping("/v1/pms/doctor-family-address-info")
public class DoctorFamilyAddressInfoController extends BaseController<DoctorFamilyAddressInfoService, DoctorFamilyAddressInfo, DoctorFamilyAddressInfoParam> {

    @Value("${gaode.map.host}")
    public String host;

    @Value("${gaode.map.key}")
    public String key;

    @Resource
    public void setService(DoctorFamilyAddressInfoService service) {
        this.service = service;
    }

    /**
     * 新增
     *
     * @param entity 要新增的对象
     * @return 新增的对象
     */
    @PostMapping("/")
    @Operation(summary = "新增")
    @Override
    public ApiResponse<DoctorFamilyAddressInfo> add(@RequestBody DoctorFamilyAddressInfo entity, @AuthUser User user) {
        entity.setEditorId(user.getId());
        entity.setEditorName(user.getUsername());
        entity.setDefault().validate(true);


        //根据地址获取gps坐标
        String location = mapToGeo(entity.getProvince() + entity.getCity() + entity.getDistrict() + entity.getDetailAddress());
        if(StringUtils.isEmpty(location)){
            throw new RuntimeException("地址转化失败");
        }
        String[] split = location.split(",");
        entity.setLng(split[0]);
        entity.setLat(split[1]);

        this.service.save(entity);
        return ApiResponse.ok(this.service.getById(entity.getId()));
    }

    /**
     * 更新
     *
     * @param entity 要更新的对象
     * @return 更新后的对象
     */
    @PutMapping("/")
    @Operation(summary = "更新")
    @ApiCommon
    @Override
    public ApiResponse<DoctorFamilyAddressInfo> update(
            @RequestBody DoctorFamilyAddressInfo entity,
            @RequestParam(value = "updateAllFields", defaultValue = "false") boolean updateAllFields,
            @AuthUser User user) {
        //根据地址获取gps坐标
        String location = mapToGeo(entity.getProvince() + entity.getCity() + entity.getDistrict() + entity.getDetailAddress());
        if(StringUtils.isEmpty(location)){
            throw new RuntimeException("地址转化失败");
        }
        String[] split = location.split(",");
        entity.setLng(split[0]);
        entity.setLat(split[1]);

        if (updateAllFields) {
            this.service.updateAllFieldsById(entity);
        } else {
            this.service.updateById(entity);
        }
        return ApiResponse.ok(this.service.getById(entity.getId()));
    }

    /**
     * 批量新增
     *
     * @param entityList 要新增的对象
     * @return boolean 成功或失败
     */
    @PostMapping("/batch-save")
    @Operation(summary = "批量新增")
    @Override
    public ApiResponse<Boolean> batchSave(@RequestBody List<DoctorFamilyAddressInfo> entityList, @AuthUser User user) {
        entityList.forEach(entity -> {
            entity.setEditorId(user.getId());
            entity.setEditorName(user.getUsername());
            entity.setDefault().validate(true);
        });
        return ApiResponse.ok(this.service.saveBatch(entityList));
    }

    /**
     * 审核通过
     */
    @PostMapping("/auditPass/{id}")
    @Operation(summary = "审核通过")
    public ApiResponse auditPass(@PathVariable("id") Long id, @AuthUser User user) {
        return ApiResponse.ok(this.service.auditPass(id,user));
    }

    /**
     * 审核失败
     */
    @PostMapping("/auditFail/{id}")
    @Operation(summary = "审核失败")
    public ApiResponse auditFail(@PathVariable("id") Long id,@RequestParam("reason") String rejectReason, @AuthUser User user) {
        return ApiResponse.ok(this.service.auditFail(id, rejectReason,user));
    }

    @PostMapping("/test")
    @Operation(summary = "test")
    public ApiResponse auditFail(@RequestParam("address") String address) {
        String location = mapToGeo(address);
        return ApiResponse.ok(location);
    }

    public String mapToGeo(String address) {
        String location = "";
        Retrofit retrofit = new Retrofit.Builder()
                .baseUrl(host)
                .addConverterFactory(GsonConverterFactory.create())
                .client(new OkHttpClient.Builder().build())
                .build();
        MapApiService service = retrofit.create(MapApiService.class);


        log.info("地址转化中，地址{}",address);
        Call<JsonObject> call = service.geo(key, address);
        try {
            Response<JsonObject> execute = call.execute();
            log.info("返回结果{}",execute.toString());
            JsonObject body = execute.body();
            if (body != null) {
                String status = body.get("status").getAsString();
                if ("1".equals(status)) {
                    JsonObject geocodes = body.getAsJsonArray("geocodes").get(0).getAsJsonObject();
                    location = geocodes.get("location").getAsString();
                }
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return location;
    }

    //todo 获取用户定位gps,推荐附近的医生
    /**
     * 根据地址查询附近医生列表
     */
    @GetMapping("/queryNearbyDoctorList")
    @Operation(summary = "根据地址查询附近医生列表")
    public ApiResponse queryNearbyDoctorList(@RequestParam("address") String address) {
        //根据地址获取gps坐标
        String location = mapToGeo(address);
        if(StringUtils.isEmpty(location)){
            throw new RuntimeException("地址转化失败");
        }
        String[] split = location.split(",");
        String lng = split[0];
        String lat = split[1];

        return ApiResponse.ok(this.service.queryNearbyDoctorList(lat, lng));
    }

}
