/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：医生工作时间配置表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest;

import java.util.*;

import cn.dev33.satoken.stp.SaLoginModel;
import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.xwd.hospital.server.annotation.ApiCommon;
import com.xwd.hospital.server.annotation.AuthUser;
import com.xwd.hospital.server.base.BaseController;
import com.xwd.hospital.server.domain.User;
import com.xwd.hospital.server.dto.DoctorTimeConfigDto;
import com.xwd.hospital.server.enums.YesNoEnum;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.domain.DoctorTimeConfig;
import com.xwd.hospital.server.rest.req.DoctorTimeConfigParam;
import com.xwd.hospital.server.rest.res.ApiResponse;
import com.xwd.hospital.server.service.DoctorTimeConfigService;
import com.xwd.hospital.server.service.OrderService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.scheduling.annotation.Async;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

@Slf4j
@RestController
@Tag(name = "DoctorTimeConfigController", description = "医生工作时间配置表管理")
@RequestMapping("/v1/pms/doctor-time-config")
public class DoctorTimeConfigController extends BaseController<DoctorTimeConfigService, DoctorTimeConfig, DoctorTimeConfigParam> {

    @Resource
    public void setService(DoctorTimeConfigService service) {
        this.service = service;
    }

    /**
     * 新增
     *
     * @param entity 要新增的对象
     * @return 新增的对象
     */
    @PostMapping("/")
    @Operation(summary = "新增")
    @Override
    public ApiResponse<DoctorTimeConfig> add(@RequestBody DoctorTimeConfig entity, @AuthUser User user) {
        entity.setEditorId(user.getId());
        entity.setEditorName(user.getUsername());
        entity.setDefault().validate(true);
        this.service.save(entity);
        return ApiResponse.ok(this.service.getById(entity.getId()));
    }

    /**
     * 批量新增
     *
     * @param entityList 要新增的对象
     * @return boolean 成功或失败
     */
    @PostMapping("/batch-save")
    @Operation(summary = "批量新增")
    @Override
    public ApiResponse<Boolean> batchSave(@RequestBody List<DoctorTimeConfig> entityList, @AuthUser User user) {
        entityList.forEach(entity -> {
            entity.setEditorId(user.getId());
            entity.setEditorName(user.getUsername());
            entity.setDefault().validate(true);
        });
        return ApiResponse.ok(this.service.saveBatch(entityList));
    }


    @PostMapping("/changeStatus")
    @Operation(summary = "修改工作时间状态")
    public ApiResponse changeStatus(@RequestBody List<DoctorTimeConfigDto> list) {
        this.service.changeStatus(list);
        return ApiResponse.ok(null);
    }

    @GetMapping("/listDoctorTime")
    @Operation(summary = "查看医生工作时间")
    public ApiResponse listDoctorTime(@RequestParam Long doctorId) {
        return ApiResponse.ok(this.service.listDoctorTime(doctorId));
    }


}
