package com.xwd.hospital.server.rest;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.IdcardUtil;
import cn.hutool.poi.excel.BigExcelWriter;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xwd.hospital.server.annotation.ApiCommon;
import com.xwd.hospital.server.annotation.AuthUser;
import com.xwd.hospital.server.domain.*;
import com.xwd.hospital.server.dto.*;
import com.xwd.hospital.server.enums.*;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.rest.res.ApiResponse;
import com.xwd.hospital.server.service.*;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@RestController
@Tag(name = "ExcelController", description = "excel导入")
@RequestMapping("/v1/pms/excel")
public class ExcelController {
    @Resource
    private ExcelImportInfoService excelImportInfoService;
    @Resource
    private ExcelImportInfoDetailService detailService;
    @Resource
    private ExcelService excelService;

    @GetMapping("/exportUserInfo")
    @Operation(summary = "导出用户数据")
    @ApiCommon
    public void exportUserInfo(HttpServletResponse response) {
        List<UserExcelDto> userExcelDtos = excelService.exportUserInfo();
        BigExcelWriter writer = ExcelUtil.getBigWriter();
        writer.write(userExcelDtos);
        ServletOutputStream out = null;
        try{
            response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;charset=utf-8");
            response.setHeader("Content-Disposition","attachment;filename=example.xlsx");
            out=response.getOutputStream();
            writer.flush(out);
            writer.close();
            out.close();
        }catch (Exception e){
           throw new ApiCode.ApiException(-1,"导出失败");
        }finally {
            IoUtil.close(writer);
            IoUtil.close(out);
        }
    }

    /**
     * 导入科室
     */
    @PostMapping("/importDepartments")
    @Operation(summary = "导入科室")
    @ApiCommon
    public ApiResponse importDepartments(@RequestParam MultipartFile multipartFile) {
        try {
            excelService.importDepartments(multipartFile);
        }catch (Exception e){
            return ApiResponse.fail(-1,"文件导入失败");
        }

        return ApiResponse.ok(null);
    }

    /**
     * 导入患者数据
     */
    @PostMapping("/importUser")
    @Operation(summary = "导入患者数据")
    @ApiCommon
    public ApiResponse importUser(@RequestParam MultipartFile multipartFile) {

        ExcelImportInfo excelImportInfo = new ExcelImportInfo();
        excelImportInfo.setImportType("患者数据导入");
        excelImportInfo.setImportTime(new Date());
        excelImportInfo.setFileName(multipartFile.getOriginalFilename());
        excelImportInfoService.save(excelImportInfo);

        File file = null;
        try {
            file = convertMultipartFileToFile(multipartFile);
        } catch (IOException ex) {
            excelImportInfo.setImportState(YesNoEnum.NO);
            excelImportInfo.setFailReason("文件初始化失败");
            excelImportInfoService.saveOrUpdate(excelImportInfo);
            return ApiResponse.fail(-1,excelImportInfo.getFailReason());
        }
        ExcelReader reader = ExcelUtil.getReader(file, "Sheet1");
        List<Map<String, Object>> allData = reader.readAll();
        ArrayList<ExcelImportInfoDetail> detailList = new ArrayList<>(allData.size());
        for (Map<String, Object> map : allData) {
            ExcelImportInfoDetail excelImportInfoDetail = new ExcelImportInfoDetail();
            excelImportInfoDetail.setImportId(excelImportInfo.getId());
            excelImportInfoDetail.setName(map.get("姓名").toString());
            excelImportInfoDetail.setSex(map.get("性别").toString());
            excelImportInfoDetail.setAge(map.get("年龄").toString());
            excelImportInfoDetail.setPhone(map.get("手机号").toString());
            excelImportInfoDetail.setIdNo(map.get("证件号").toString());
            excelImportInfoDetail.setProvince(map.get("省").toString());
            excelImportInfoDetail.setCity(map.get("市").toString());
            excelImportInfoDetail.setDistrict(map.get("区").toString());
            excelImportInfoDetail.setAddressDetail(map.get("详细地址").toString());
            excelImportInfoDetail.setAnamnesis(map.get("既往病史").toString());
            excelImportInfoDetail.setDrugAllergyHistory(map.get("药物过敏史").toString());
            excelImportInfoDetail.setPrescriptionTime(map.get("处方时间").toString());
            excelImportInfoDetail.setPrescriptionHospital(map.get("处方医院").toString());
            excelImportInfoDetail.setPrescriptionDepartemnt(map.get("处方科室").toString());
            excelImportInfoDetail.setPrescriptionDoctor(map.get("处方医生").toString());
            excelImportInfoDetail.setPrescriptionResult(map.get("处方结果").toString());
            excelImportInfoDetail.setReportItem(map.get("报告项目").toString());
            excelImportInfoDetail.setReportDesc(map.get("报告描述").toString());
            excelImportInfoDetail.setReportTime(map.get("报告时间").toString());
            excelImportInfoDetail.setReportHospital(map.get("报告医院").toString());
            excelImportInfoDetail.setReportDoctor(map.get("报告医生").toString());
            excelImportInfoDetail.setDoctorAsk(map.get("医生医嘱").toString());
            detailList.add(excelImportInfoDetail);
        }
        detailService.saveBatch(detailList);
        ImportResultDto importResultDto = null;
        try {
            importResultDto = excelService.importUser(allData);
        } catch (ApiCode.ApiException e) {
            excelImportInfo.setImportState(YesNoEnum.NO);
            excelImportInfo.setFailRow(Long.valueOf(e.getMessage()));
            excelImportInfo.setFailReason(701 == e.getCode()? "身份证号码不合法":702 == e.getCode()?"身份证号码不合法":"数据库异常错误");
            excelImportInfoService.saveOrUpdate(excelImportInfo);
            return ApiResponse.fail(-1,excelImportInfo.getFailReason());
        }
        if (importResultDto.isResult()){
            excelImportInfo.setImportState(YesNoEnum.YES);
            excelImportInfoService.saveOrUpdate(excelImportInfo);
            return ApiResponse.ok(null);
        }else {
            excelImportInfo.setImportState(YesNoEnum.NO);
            excelImportInfo.setFailRow(importResultDto.getRow());
            excelImportInfoService.saveOrUpdate(excelImportInfo);
            return ApiResponse.fail(-1,excelImportInfo.getFailReason());
        }

    }

    public File convertMultipartFileToFile(MultipartFile multipartFile) throws IOException {
        File file = new File(multipartFile.getOriginalFilename());
        FileUtils.writeByteArrayToFile(file, multipartFile.getBytes());
        return file;
    }




}
