/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：影像报告表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest;

import java.util.List;
import java.util.Arrays;

import cn.dev33.satoken.stp.SaLoginModel;
import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.xwd.hospital.server.annotation.ApiCommon;
import com.xwd.hospital.server.annotation.AuthUser;
import com.xwd.hospital.server.base.BaseController;
import com.xwd.hospital.server.domain.User;
import com.xwd.hospital.server.dto.DoctorAskDto;
import com.xwd.hospital.server.dto.MedicalQualificationDto;
import com.xwd.hospital.server.dto.OrderDto;
import com.xwd.hospital.server.dto.ReportDto;
import com.xwd.hospital.server.enums.OrderStateEnum;
import com.xwd.hospital.server.enums.ReportStateEnum;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.domain.MedicalReport;
import com.xwd.hospital.server.rest.req.MedicalReportParam;
import com.xwd.hospital.server.rest.res.ApiResponse;
import com.xwd.hospital.server.service.MedicalReportService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@Tag(name = "MedicalReportController", description = "影像报告表管理")
@RequestMapping("/v1/pms/medical-report")
public class MedicalReportController extends BaseController<MedicalReportService, MedicalReport, MedicalReportParam> {

    @Resource
    public void setService(MedicalReportService service) {
        this.service = service;
    }

    /**
     * 新增
     *
     * @param entity 要新增的对象
     * @return 新增的对象
     */
    @PostMapping("/")
    @Operation(summary = "新增")
    @Override
    public ApiResponse<MedicalReport> add(@RequestBody MedicalReport entity, @AuthUser User user) {
        entity.setEditorId(user.getId());
        entity.setEditorName(user.getUsername());
        entity.setDefault().validate(true);
        this.service.save(entity);
        return ApiResponse.ok(this.service.getById(entity.getId()));
    }

    /**
     * 批量新增
     *
     * @param entityList 要新增的对象
     * @return boolean 成功或失败
     */
    @PostMapping("/batch-save")
    @Operation(summary = "批量新增")
    @Override
    public ApiResponse<Boolean> batchSave(@RequestBody List<MedicalReport> entityList, @AuthUser User user) {
        entityList.forEach(entity -> {
            entity.setEditorId(user.getId());
            entity.setEditorName(user.getUsername());
            entity.setDefault().validate(true);
        });
        return ApiResponse.ok(this.service.saveBatch(entityList));
    }

    /**
     * 分页查询
     *
     * @param param 查询参数
     * @param pageNum pageNum
     * @param pageSize pageSize
     * @return
     */
    @GetMapping("/searchReportList")
    @Operation(summary = "小程序端查询医生可看报告")
    @ApiCommon
    public ApiResponse<IPage<MedicalReport>> searchReportList(
            MedicalReportParam param,
            @RequestParam(value = "orderByClause", defaultValue = "id desc") String orderByClause,
            @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
            @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize
    ) {
//        QueryWrapper<MedicalReport> wrapper = param.toQueryWrapper();
//        String[] temp = orderByClause.split("[,;]");
//        Arrays.stream(temp).forEach(ob -> {
//            String[] obTemp = ob.split("\\s");
//            boolean isAsc = obTemp.length == 1 || obTemp[1].equalsIgnoreCase("asc");
//            wrapper.orderBy(true, isAsc, obTemp[0]);
//        });

        Page<MedicalReport> page = new Page<>(pageNum, pageSize);

        return ApiResponse.ok(this.service.searchReportList(page,param.getDoctorId(),null == param.getReportState()?null:param.getReportState().toString()));
    }

    /**
     * 小程序患者端查询列表
     *
     * @param param 查询参数
     * @param pageNum pageNum
     * @param pageSize pageSize
     * @return
     */
    @GetMapping("/searchForPatient")
    @Operation(summary = "小程序患者端查询列表")
    @ApiCommon
    public ApiResponse<IPage<MedicalReport>> searchForPatient(
            MedicalReportParam param,
            @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
            @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize
    ) {

        Page<MedicalReport> page = new Page<>(pageNum, pageSize);

        return ApiResponse.ok(this.service.searchReportListForPatient(page,param.getPatientIdNo(),null == param.getReportState()?null:param.getReportState().toString()));
    }
    /**
     * 小程序患者端报告详情
     * @return
     */
    @GetMapping("/searchForPatient/{id}")
    @Operation(summary = "小程序患者端报告详情")
    @ApiCommon
    public ApiResponse<MedicalReport> searchForPatient(@PathVariable("id") Long id) {

        return ApiResponse.ok(this.service.searchForPatient(id));
    }

    /**
     * 上传影像报告
     *
     */
    @PostMapping("/uploadReport")
    @Operation(summary = "上传影像报告")
    public ApiResponse uploadReport(@RequestBody ReportDto dto, @AuthUser User user) {
        boolean result = this.service.uploadReport(dto);
        if(result){
            return ApiResponse.ok(result);
        }else {
            return ApiResponse.fail(ApiCode.FAILED.getCode(),"身份证信息不正确");
        }

    }

    /**
     * 修改影像报告
     *
     */
    @PostMapping("/updateReport")
    @Operation(summary = "修改影像报告")
    public ApiResponse updateReport(@RequestBody ReportDto dto, @AuthUser User user) {
        boolean result = this.service.updateReport(dto);
        if(result){
            return ApiResponse.ok(result);
        }else {
            return ApiResponse.fail(ApiCode.FAILED.getCode(),"身份证信息不正确");
        }

    }

    /**
     * 我的医嘱
     *
     */
    @GetMapping("/myDoctorAsk")
    @Operation(summary = "我的医嘱")
    public ApiResponse myDoctorAsk(@AuthUser User user) {

        return ApiResponse.ok(this.service.myDoctorAsk());
    }

    /**
     * 医生医嘱列表
     *
     */
    @GetMapping("/queryDoctorAskList")
    @Operation(summary = "医生医嘱列表")
    public ApiResponse queryDoctorAskList(@RequestParam(value = "state",required = false) ReportStateEnum state,
                                          @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                          @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        Page<DoctorAskDto> page = new Page<>(pageNum, pageSize);
        return ApiResponse.ok(this.service.queryDoctorAskList(page,null == state?null:state.toString()));
    }

}
