/**
 * 项目：互联网医疗
 *
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest;

import com.aspose.imaging.Image;
import com.aspose.imaging.ImageOptionsBase;
import com.aspose.imaging.imageoptions.Jpeg2000Options;
import com.aspose.imaging.imageoptions.JpegOptions;
import com.xwd.hospital.server.annotation.ApiCommon;;

import com.xwd.hospital.server.dto.PictureDto;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.rest.res.ApiResponse;
import com.xwd.hospital.server.util.FileUtils;
import com.xwd.hospital.server.util.TencentCOSUtil;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;


import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.imageio.ImageIO;
import javax.imageio.spi.ImageReaderSpi;

import java.awt.image.BufferedImage;
import java.io.*;
import java.nio.file.Files;
import java.util.Iterator;
import java.util.UUID;

@Tag(name = "UploadController", description = "文件上传")
@Slf4j
@RestController
@RequestMapping("/v1/system/upload")
public class UploadController {

    @Resource
    private TencentCOSUtil tencentCOSUtil;

    @Operation(summary = "文件上传")
    @PostMapping
    @ApiCommon
    public ApiResponse upload(@RequestParam MultipartFile file) {
        String upload = tencentCOSUtil.upLoadFile(file);
        return ApiResponse.ok(upload);
    }


    @Operation(summary = "CT报告上传")
    @PostMapping("/uploadCTFile")
    @ApiCommon
    public ApiResponse uploadCTFile(@RequestParam MultipartFile file) {

        PictureDto pictureDto = new PictureDto();
        String sourceFileUrl = tencentCOSUtil.upLoadFile(file);
        pictureDto.setSourceFileUrl(sourceFileUrl);

        if (hasDicomExtension(file)) {
            //dicom文件，需要转化成jpeg
            try {
                String fileUrl = convertDicomToJpg(file);
                File temporaryFile = new File(fileUrl);
                String temporaryFileUrl = tencentCOSUtil.upLoadTemporaryFile(temporaryFile);
                pictureDto.setImageUrl(temporaryFileUrl);
                Files.delete(temporaryFile.toPath());
            } catch (Exception e) {
                throw new ApiCode.ApiException(-1, "dicom文件转换失败");
            }

        } else {
            //非dicom文件，直接上传
            pictureDto.setImageUrl(sourceFileUrl);
        }
        return ApiResponse.ok(pictureDto);
    }

    public static boolean hasDicomExtension(MultipartFile file) {
        String fileName = file.getOriginalFilename();
        // Check if the file has a ".dcm" extension
        return fileName.toLowerCase().endsWith(".dcm");
    }

    public static String convertDicomToJpg(MultipartFile dicomFile) throws IOException {

        try (InputStream inputStream = dicomFile.getInputStream();
             Image image = Image.load(inputStream)) {

            ImageOptionsBase exportOptions = new JpegOptions();
            // 创建临时文件
            String jpgFile = UUID.randomUUID().toString() + ".jpeg";
//            String jpgFile = String.format("%s\\%s\\%s-%s-to-%s.%s", templatesFolder, "convert", "convert-", "", "jpg", "jpg");
            image.save(jpgFile, exportOptions);
            System.out.println("File saved: " + jpgFile);
            return jpgFile;
        } catch (Exception e) {
            e.printStackTrace();
            throw new ApiCode.ApiException(-1, "dicom文件转换失败");
        }
    }


}
