/**
 * 项目：互联网医疗
 * 模型分组：系统管理
 * 模型名称：用户表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest;

import java.io.IOException;
import java.io.OutputStream;
import java.util.List;
import java.util.Arrays;

import cn.binarywang.wx.miniapp.bean.urllink.GenerateUrlLinkRequest;
import cn.binarywang.wx.miniapp.util.WxMaConfigHolder;
import cn.dev33.satoken.secure.SaSecureUtil;
import cn.dev33.satoken.stp.SaLoginModel;
import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.xwd.hospital.server.annotation.ApiCommon;
import com.xwd.hospital.server.annotation.AuthUser;
import com.xwd.hospital.server.base.BaseController;
import com.xwd.hospital.server.domain.User;
import com.xwd.hospital.server.dto.*;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.domain.User;
import com.xwd.hospital.server.rest.req.UserParam;
import com.xwd.hospital.server.rest.res.ApiResponse;
import com.xwd.hospital.server.service.UserService;
import com.xwd.hospital.server.service.impl.UserServiceImpl;
import com.xwd.hospital.server.util.TencentOCRUtil;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.error.WxErrorException;
import org.springdoc.core.annotations.ParameterObject;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@Tag(name = "UserController", description = "用户表管理")
@RequestMapping("/v1/system/user")
public class UserController extends BaseController<UserService, User, UserParam> {

    @Resource
    public void setService(UserService service) {
        this.service = service;
    }
    @Resource
    public TencentOCRUtil tencentOCRUtil;

    /**
     * 新增
     *
     * @param entity 要新增的对象
     * @return 新增的对象
     */
    @PostMapping("/")
    @Operation(summary = "新增")
    @Override
    public ApiResponse<User> add(@RequestBody User entity, @AuthUser User user) {
        entity.setEditorId(user.getId());
        entity.setEditorName(user.getUsername());
        if (!StringUtils.isEmpty(entity.getPassword())) {
            entity.setPassword(SaSecureUtil.sha256(entity.getPassword()));
        }
        entity.setDefault().validate(true);
        this.service.save(entity);
        return ApiResponse.ok(this.service.getById(entity.getId()));
    }
    /**
     * 更新
     *
     * @param entity 要更新的对象
     * @return 更新后的对象
     */
    @PutMapping("/")
    @Operation(summary = "更新")
    @Override
    public ApiResponse<User> update(
            @RequestBody User entity,
            @RequestParam(value = "updateAllFields", defaultValue = "false") boolean updateAllFields,
            @AuthUser User user) {
        if (!org.springframework.util.StringUtils.isEmpty(entity.getPassword())) {
            entity.setPassword(SaSecureUtil.sha256(entity.getPassword()));
        }
        if (updateAllFields) {
            this.service.updateAllFieldsById(entity);
        } else {
            this.service.updateById(entity);
        }
        return ApiResponse.ok(this.service.getById(entity.getId()));
    }

    /**
     * 批量新增
     *
     * @param entityList 要新增的对象
     * @return boolean 成功或失败
     */
    @PostMapping("/batch-save")
    @Operation(summary = "批量新增")
    @Override
    public ApiResponse<Boolean> batchSave(@RequestBody List<User> entityList, @AuthUser User user) {
        entityList.forEach(entity -> {
            entity.setEditorId(user.getId());
            entity.setEditorName(user.getUsername());
            entity.setDefault().validate(true);
        });
        return ApiResponse.ok(this.service.saveBatch(entityList));
    }

    /**
     * 分页查询
     *
     * @param param 查询参数
     * @param pageNum pageNum
     * @param pageSize pageSize
     * @return int
     */
    @GetMapping("/search")
    @Operation(summary = "分页查询")
    @Override
    public ApiResponse<IPage<User>> selectByPage(
        UserParam param,
        @RequestParam(value = "orderByClause", defaultValue = "id desc") String orderByClause,
        @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
        @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize
    ) {
        QueryWrapper<User> wrapper = param.toQueryWrapper();
        String[] temp = orderByClause.split("[,;]");
        Arrays.stream(temp).forEach(ob -> {
            String[] obTemp = ob.split("\\s");
            boolean isAsc = obTemp.length == 1 || obTemp[1].equalsIgnoreCase("asc");
            wrapper.orderBy(true, isAsc, obTemp[0]);
        });
        IPage<User> page = new Page<>(pageNum, pageSize);
        return ApiResponse.ok(this.service.page(page, wrapper));
    }
    /**
     * <pre>
     * 用户登陆接口
     * </pre>
     */
    @Operation(summary = "用户登陆接口")
    @PostMapping("/login")
    @ApiCommon
    public ApiResponse<Map> login(@RequestBody User user) {
        Map<String, Object> result = new HashMap<>();
        User loginUser = this.service.login(user.getUsername(), user.getPassword());
        result.put("userInfo", loginUser);
        var loginModel = new SaLoginModel();
        loginModel.setExtra("userId", loginUser.getId());
        StpUtil.login(loginUser.getUsername(), loginModel);
        result.put("token", StpUtil.getTokenValue());
        return ApiResponse.ok(result);
    }

    /**
     * <pre>
     * 管理端用户短信验证码登陆接口
     * </pre>
     */
    @Operation(summary = "管理端用户短信验证码登陆接口")
    @PostMapping("/smsCodeLogin")
    @ApiCommon
    public ApiResponse<Map> smsCodeLogin(@RequestBody SmsCodeLoginDto dto) {
        Map<String, Object> result = new HashMap<>();
        User loginUser = this.service.smsCodeLogin(dto.getPhone(), dto.getCode());
        result.put("userInfo", loginUser);
        var loginModel = new SaLoginModel();
        loginModel.setExtra("userId", loginUser.getId());
        StpUtil.login(loginUser.getUsername(), loginModel);
        result.put("token", StpUtil.getTokenValue());
        return ApiResponse.ok(result);
    }

     /**
     * <pre>
     * 用户登出接口
     * </pre>
     */
    @Operation(summary = "用户登出接口")
    @PostMapping("/logout")
    @ApiCommon
    public ApiResponse<Object> logout() {
        StpUtil.logout();
        return ApiResponse.ok(null);
    }

    /**
     * <pre>
     * 用户注册接口
     * </pre>
     */
    @Operation(summary = "用户注册接口")
    @PostMapping("/register")
    @ApiCommon
    public ApiResponse<User> register(@RequestBody User user) {
        return ApiResponse.ok(this.service.register(user, "ROLE_USER"));
    }

    /**
     * <pre>
     * 检查用户名
     * </pre>
     */
    @Operation(summary = "检查用户名")
    @PostMapping("/checkUserName")
    @ApiCommon
    public ApiResponse<Boolean> checkUserName(@RequestParam("username") String username) {
        return ApiResponse.ok(this.service.checkUserName(username));
    }

    /**
     * <pre>
     * 微信获取用户手机号码接口
     * </pre>
     */
    @Operation(summary = "微信获取用户手机号码接口")
    @PostMapping("/getPhoneNumber")
    @ApiCommon
    public ApiResponse getPhoneNumber(@RequestBody LoginDto loginDto) {
        return ApiResponse.ok(this.service.getPhoneNumber(loginDto));
    }

    /**
     * <pre>
     * 小程序更新用户信息
     * </pre>
     */
    @Operation(summary = "小程序更新用户信息")
    @PostMapping("/updateUserInfo")
    @ApiCommon
    public ApiResponse updateUserInfo(@RequestBody UpdateUserInfoDto updateInfoDto,@AuthUser User user) {
        UserDto userDto = this.service.updateUserInfo(updateInfoDto);
        if(null == userDto){
            return ApiResponse.fail(ApiCode.FAILED.getCode(),"身份证号码验证不正确");
        }else {
            return ApiResponse.ok(userDto);
        }
    }

    /**
     * <pre>
     * 用户登陆接口
     * </pre>
     */
    @Operation(summary = "小程序用户登陆接口")
    @PostMapping("/miniAppLogin")
    @ApiCommon
    public ApiResponse<Map> miniAppLogin(@RequestBody LoginDto loginDto) {
        Map<String, Object> result = new HashMap<>();
        UserDto userDto = this.service.miniAppLogin(loginDto);
        result.put("userDto", userDto);
        if(userDto.isRegisterFlag()){
            return ApiResponse.ok(result);
        }
        var loginModel = new SaLoginModel();
        loginModel.setExtra("userId", userDto.getUser().getId());
        StpUtil.login(userDto.getUser().getId(), loginModel);
        result.put("token", StpUtil.getTokenValue());

        return ApiResponse.ok(result);
    }

    /**
     * <pre>
     * 小程序注册接口
     * </pre>
     */
    @Operation(summary = "小程序注册接口")
    @PostMapping("/miniAppRegister")
    @ApiCommon
    public ApiResponse<Map> miniAppRegister(@RequestBody RegisterDto registserDto) {
        Map<String, Object> result = new HashMap<>();
        UserDto userDto = this.service.miniAppRegister(registserDto);

        result.put("userDto", userDto);
        var loginModel = new SaLoginModel();
        loginModel.setExtra("userId", userDto.getUser().getId());
        StpUtil.login(userDto.getUser().getId(), loginModel);
        result.put("token", StpUtil.getTokenValue());

        return ApiResponse.ok(result);
    }

    /**
     * <pre>
     * 微信信息修改
     * </pre>
     */
    @Operation(summary = "微信信息修改")
    @PostMapping("/wxUpdate")
    @Deprecated
    @ApiCommon
    public ApiResponse wxUpdate(@RequestBody UpdateInfoDto updateUserDto) {
        return ApiResponse.ok(this.service.wxUpdate(updateUserDto));
    }

    /**
     * <pre>
     * 查询当前登录的用户信息
     * </pre>
     */
    @Operation(summary = "查询当前登录的用户信息")
    @GetMapping("/info")
    @ApiCommon
    public ApiResponse<User> currentUserInfo(@AuthUser(queryDb = true) User user) {
        return ApiResponse.ok(user);
    }

    @PostMapping("/change-password")
    @Operation(summary = "修改密码")
    @ApiCommon
    public ApiResponse<User> updatePassword(@RequestBody PasswordDto passwordDto) {
        User user = this.service.getById(passwordDto.getUserId());
        if (null != user) {
            if (user.getPassword().equals(SaSecureUtil.sha256(passwordDto.getOldPassword()))){
                user.setPassword(SaSecureUtil.sha256(passwordDto.getNewPassword()));
                this.service.updateById(user);
            } else {
                return ApiResponse.fail(-1, "原密码不正确");
            }
        }
        return ApiResponse.ok(user);
    }

//    /**
//     * <pre>
//     * test
//     * </pre>
//     */
//    @Operation(summary = "test")
//    @GetMapping("/test")
//    @ApiCommon
//    public ApiResponse test(@RequestParam(value = "imUserId") String imUserId,
//                             @RequestParam(value = "nickName") String nickName,
//                             @RequestParam(value = "headUrl") String headUrl) {
//        this.service.addUserToIMSystem(imUserId, nickName, headUrl);
//        return ApiResponse.ok(null);
//    }

    /**
     * <pre>
     * 获取IM签名
     * </pre>
     */
    @Operation(summary = "获取IM签名")
    @GetMapping("/getUserSig")
    @ApiCommon
    public ApiResponse getUserSig(@AuthUser User user) {
        Object userId = StpUtil.getExtra("userId");

        return ApiResponse.ok(this.service.getIMSig(Long.valueOf(userId.toString())));
    }

    /**
     * <pre>
     * 获取小程序推广码
     * </pre>
     */
    @Operation(summary = "获取小程序推广码")
    @GetMapping("/getWxQrCode")
    @ApiCommon
    public void getWxQrCode(@AuthUser User user, HttpServletResponse response) {
        try{
            OutputStream stream = null;
            Object userId = StpUtil.getExtra("userId");
            byte[] result = this.service.getWxQrCode(Long.valueOf(userId.toString()));
            //输出图片到页面
            response.setContentType("image/png");
            stream = response.getOutputStream();
            stream.write(result);
            stream.flush();
            stream.close();
        }catch (IOException e){
            e.printStackTrace();
        }
    }

    /**
     * <pre>
     * 身份证OCR识别
     * </pre>
     */
    @Operation(summary = "身份证OCR识别")
    @PostMapping("/idCardOCR")
    @ApiCommon
    public ApiResponse idCardOCR(@AuthUser User user,@RequestBody String image) {
        return ApiResponse.ok(tencentOCRUtil.idCardOcr(image));
    }

    /**
     * <pre>
     * 获取病例与报告数量
     * </pre>
     */
    @Operation(summary = "获取病例与报告数量")
    @GetMapping("/getUserCaseAndReportCount/{userInfoId}")
    @ApiCommon
    public ApiResponse<CaseAndReportCountDto> getUserCaseAndReportCount(@PathVariable("userInfoId") Long userInfoId) {

        return ApiResponse.ok(this.service.getUserCaseAndReportCount(userInfoId));
    }

    @PostMapping("/test")
    @Operation(summary = "test")
    public ApiResponse test(@RequestParam("doctorId") Long doctorId) {
        this.service.createDoctorWorkTime(doctorId);
        return ApiResponse.ok(null);
    }

    @PostMapping("/getUrlLink")
    @Operation(summary = "getUrlLink")
    public ApiResponse<String> getUrlLink() {
        return ApiResponse.ok(this.service.getUrlLink());
    }
}
