/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：优惠券发放记录表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.hospital.server.base.BaseParam;
import com.xwd.hospital.server.enums.CouponTypeEnum;
import com.xwd.hospital.server.domain.CouponSendRecord;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class CouponSendRecordParam extends BaseParam<CouponSendRecord> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 优惠券Id
     */
    @Parameter(description = "优惠券Id")
    private Long couponId;
    /**
     * 优惠券名称
     */
    @Parameter(description = "优惠券名称")
    private String couponName;
    /**
     * 优惠券类型
     */
    @Parameter(description = "优惠券类型")
    private CouponTypeEnum couponType;
    /**
     * 优惠券类型 IN值List
     */
    @Parameter(description = "优惠券类型 IN值List")
    private List<String> couponTypeList;
    /**
     * 优惠金额/折扣
     */
    @Parameter(description = "优惠金额/折扣")
    private java.math.BigDecimal couponDiscount;
    /**
     * 发放人员id
     */
    @Parameter(description = "发放人员id")
    private Long sendId;
    /**
     * 发放原因
     */
    @Parameter(description = "发放原因")
    private String sendReason;
    /**
     * 职业Id
     */
    @Parameter(description = "职业Id")
    private Long careerId;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<CouponSendRecord> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<CouponSendRecord> toQueryWrapper(String columnPrefix) {
        QueryWrapper<CouponSendRecord> wrapper = Wrappers.<CouponSendRecord>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        wrapper.eq(this.getCouponId() != null, columnPrefix + "coupon_id", this.getCouponId());
        if (this.getCouponName() != null) {
            if (this.getCouponName().startsWith("%") && this.getCouponName().endsWith("%")) {
                wrapper.like(columnPrefix + "coupon_name", this.getCouponName().substring(1, this.getCouponName().length() - 1));
            } else if (this.getCouponName().startsWith("%") && !this.getCouponName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "coupon_name", this.getCouponName().substring(1));
            } else if (this.getCouponName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "coupon_name", this.getCouponName().substring(0, this.getCouponName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "coupon_name", this.getCouponName());
            }
        }
        wrapper.eq(this.getCouponType() != null, columnPrefix + "coupon_type", this.getCouponType());
        wrapper.in(this.getCouponTypeList() != null && this.getCouponTypeList().size() > 0, columnPrefix + "coupon_type", this.getCouponTypeList());
        wrapper.eq(this.getCouponDiscount() != null, columnPrefix + "coupon_discount", this.getCouponDiscount());
        wrapper.eq(this.getSendId() != null, columnPrefix + "send_id", this.getSendId());
        if (this.getSendReason() != null) {
            if (this.getSendReason().startsWith("%") && this.getSendReason().endsWith("%")) {
                wrapper.like(columnPrefix + "send_reason", this.getSendReason().substring(1, this.getSendReason().length() - 1));
            } else if (this.getSendReason().startsWith("%") && !this.getSendReason().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "send_reason", this.getSendReason().substring(1));
            } else if (this.getSendReason().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "send_reason", this.getSendReason().substring(0, this.getSendReason().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "send_reason", this.getSendReason());
            }
        }
        wrapper.eq(this.getCareerId() != null, columnPrefix + "career_id", this.getCareerId());
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
