/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：日常疾病配置表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.hospital.server.base.BaseParam;
import com.xwd.hospital.server.domain.DiseaseConfig;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class DiseaseConfigParam extends BaseParam<DiseaseConfig> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 疾病名称
     */
    @Parameter(description = "疾病名称")
    private String diseaseName;
    /**
     * 疾病描述
     */
    @Parameter(description = "疾病描述")
    private String diseaseDesc;
    /**
     * 常见症状
     */
    @Parameter(description = "常见症状")
    private String commonSymptoms;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<DiseaseConfig> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<DiseaseConfig> toQueryWrapper(String columnPrefix) {
        QueryWrapper<DiseaseConfig> wrapper = Wrappers.<DiseaseConfig>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        if (this.getDiseaseName() != null) {
            if (this.getDiseaseName().startsWith("%") && this.getDiseaseName().endsWith("%")) {
                wrapper.like(columnPrefix + "disease_name", this.getDiseaseName().substring(1, this.getDiseaseName().length() - 1));
            } else if (this.getDiseaseName().startsWith("%") && !this.getDiseaseName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "disease_name", this.getDiseaseName().substring(1));
            } else if (this.getDiseaseName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "disease_name", this.getDiseaseName().substring(0, this.getDiseaseName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "disease_name", this.getDiseaseName());
            }
        }
        if (this.getDiseaseDesc() != null) {
            if (this.getDiseaseDesc().startsWith("%") && this.getDiseaseDesc().endsWith("%")) {
                wrapper.like(columnPrefix + "disease_desc", this.getDiseaseDesc().substring(1, this.getDiseaseDesc().length() - 1));
            } else if (this.getDiseaseDesc().startsWith("%") && !this.getDiseaseDesc().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "disease_desc", this.getDiseaseDesc().substring(1));
            } else if (this.getDiseaseDesc().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "disease_desc", this.getDiseaseDesc().substring(0, this.getDiseaseDesc().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "disease_desc", this.getDiseaseDesc());
            }
        }
        if (this.getCommonSymptoms() != null) {
            if (this.getCommonSymptoms().startsWith("%") && this.getCommonSymptoms().endsWith("%")) {
                wrapper.like(columnPrefix + "common_symptoms", this.getCommonSymptoms().substring(1, this.getCommonSymptoms().length() - 1));
            } else if (this.getCommonSymptoms().startsWith("%") && !this.getCommonSymptoms().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "common_symptoms", this.getCommonSymptoms().substring(1));
            } else if (this.getCommonSymptoms().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "common_symptoms", this.getCommonSymptoms().substring(0, this.getCommonSymptoms().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "common_symptoms", this.getCommonSymptoms());
            }
        }
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
