/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：医生工作时间配置表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.hospital.server.base.BaseParam;
import com.xwd.hospital.server.enums.YesNoEnum;
import com.xwd.hospital.server.domain.DoctorTimeConfig;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class DoctorTimeConfigParam extends BaseParam<DoctorTimeConfig> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 医生Id
     */
    @Parameter(description = "医生Id")
    private Long doctorId;
    /**
     * 工作日期
     */
    @Parameter(description = "工作日期")
    private String workDay;
    /**
     * 工作时间段
     */
    @Parameter(description = "工作时间段")
    private String workTime;
    /**
     * 工作状态
     */
    @Parameter(description = "工作状态")
    private YesNoEnum workStatus;
    /**
     * 工作状态 IN值List
     */
    @Parameter(description = "工作状态 IN值List")
    private List<String> workStatusList;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<DoctorTimeConfig> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<DoctorTimeConfig> toQueryWrapper(String columnPrefix) {
        QueryWrapper<DoctorTimeConfig> wrapper = Wrappers.<DoctorTimeConfig>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        wrapper.eq(this.getDoctorId() != null, columnPrefix + "doctor_id", this.getDoctorId());
        if (this.getWorkDay() != null) {
            if (this.getWorkDay().startsWith("%") && this.getWorkDay().endsWith("%")) {
                wrapper.like(columnPrefix + "work_day", this.getWorkDay().substring(1, this.getWorkDay().length() - 1));
            } else if (this.getWorkDay().startsWith("%") && !this.getWorkDay().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "work_day", this.getWorkDay().substring(1));
            } else if (this.getWorkDay().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "work_day", this.getWorkDay().substring(0, this.getWorkDay().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "work_day", this.getWorkDay());
            }
        }
        if (this.getWorkTime() != null) {
            if (this.getWorkTime().startsWith("%") && this.getWorkTime().endsWith("%")) {
                wrapper.like(columnPrefix + "work_time", this.getWorkTime().substring(1, this.getWorkTime().length() - 1));
            } else if (this.getWorkTime().startsWith("%") && !this.getWorkTime().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "work_time", this.getWorkTime().substring(1));
            } else if (this.getWorkTime().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "work_time", this.getWorkTime().substring(0, this.getWorkTime().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "work_time", this.getWorkTime());
            }
        }
        wrapper.eq(this.getWorkStatus() != null, columnPrefix + "work_status", this.getWorkStatus());
        wrapper.in(this.getWorkStatusList() != null && this.getWorkStatusList().size() > 0, columnPrefix + "work_status", this.getWorkStatusList());
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
