/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：信息导入详情表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.hospital.server.base.BaseParam;
import com.xwd.hospital.server.domain.ExcelImportInfoDetail;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class ExcelImportInfoDetailParam extends BaseParam<ExcelImportInfoDetail> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 导入记录Id
     */
    @Parameter(description = "导入记录Id")
    private Long importId;
    /**
     * 姓名
     */
    @Parameter(description = "姓名")
    private String name;
    /**
     * 性别
     */
    @Parameter(description = "性别")
    private String sex;
    /**
     * 年龄
     */
    @Parameter(description = "年龄")
    private String age;
    /**
     * 手机号
     */
    @Parameter(description = "手机号")
    private String phone;
    /**
     * 证件号
     */
    @Parameter(description = "证件号")
    private String idNo;
    /**
     * 省
     */
    @Parameter(description = "省")
    private String province;
    /**
     * 市
     */
    @Parameter(description = "市")
    private String city;
    /**
     * 区
     */
    @Parameter(description = "区")
    private String district;
    /**
     * 详细地址
     */
    @Parameter(description = "详细地址")
    private String addressDetail;
    /**
     * 既往病史
     */
    @Parameter(description = "既往病史")
    private String anamnesis;
    /**
     * 药物过敏史
     */
    @Parameter(description = "药物过敏史")
    private String drugAllergyHistory;
    /**
     * 处方时间
     */
    @Parameter(description = "处方时间")
    private String prescriptionTime;
    /**
     * 处方医院
     */
    @Parameter(description = "处方医院")
    private String prescriptionHospital;
    /**
     * 处方科室
     */
    @Parameter(description = "处方科室")
    private String prescriptionDepartemnt;
    /**
     * 处方医生
     */
    @Parameter(description = "处方医生")
    private String prescriptionDoctor;
    /**
     * 处方结果
     */
    @Parameter(description = "处方结果")
    private String prescriptionResult;
    /**
     * 报告项目
     */
    @Parameter(description = "报告项目")
    private String reportItem;
    /**
     * 报告描述
     */
    @Parameter(description = "报告描述")
    private String reportDesc;
    /**
     * 报告时间
     */
    @Parameter(description = "报告时间")
    private String reportTime;
    /**
     * 报告医院
     */
    @Parameter(description = "报告医院")
    private String reportHospital;
    /**
     * 报告医生
     */
    @Parameter(description = "报告医生")
    private String reportDoctor;
    /**
     * 医生医嘱
     */
    @Parameter(description = "医生医嘱")
    private String doctorAsk;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ExcelImportInfoDetail> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ExcelImportInfoDetail> toQueryWrapper(String columnPrefix) {
        QueryWrapper<ExcelImportInfoDetail> wrapper = Wrappers.<ExcelImportInfoDetail>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        wrapper.eq(this.getImportId() != null, columnPrefix + "import_id", this.getImportId());
        if (this.getName() != null) {
            if (this.getName().startsWith("%") && this.getName().endsWith("%")) {
                wrapper.like(columnPrefix + "name", this.getName().substring(1, this.getName().length() - 1));
            } else if (this.getName().startsWith("%") && !this.getName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "name", this.getName().substring(1));
            } else if (this.getName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "name", this.getName().substring(0, this.getName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "name", this.getName());
            }
        }
        if (this.getSex() != null) {
            if (this.getSex().startsWith("%") && this.getSex().endsWith("%")) {
                wrapper.like(columnPrefix + "sex", this.getSex().substring(1, this.getSex().length() - 1));
            } else if (this.getSex().startsWith("%") && !this.getSex().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "sex", this.getSex().substring(1));
            } else if (this.getSex().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "sex", this.getSex().substring(0, this.getSex().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "sex", this.getSex());
            }
        }
        if (this.getAge() != null) {
            if (this.getAge().startsWith("%") && this.getAge().endsWith("%")) {
                wrapper.like(columnPrefix + "age", this.getAge().substring(1, this.getAge().length() - 1));
            } else if (this.getAge().startsWith("%") && !this.getAge().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "age", this.getAge().substring(1));
            } else if (this.getAge().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "age", this.getAge().substring(0, this.getAge().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "age", this.getAge());
            }
        }
        if (this.getPhone() != null) {
            if (this.getPhone().startsWith("%") && this.getPhone().endsWith("%")) {
                wrapper.like(columnPrefix + "phone", this.getPhone().substring(1, this.getPhone().length() - 1));
            } else if (this.getPhone().startsWith("%") && !this.getPhone().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "phone", this.getPhone().substring(1));
            } else if (this.getPhone().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "phone", this.getPhone().substring(0, this.getPhone().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "phone", this.getPhone());
            }
        }
        if (this.getIdNo() != null) {
            if (this.getIdNo().startsWith("%") && this.getIdNo().endsWith("%")) {
                wrapper.like(columnPrefix + "id_no", this.getIdNo().substring(1, this.getIdNo().length() - 1));
            } else if (this.getIdNo().startsWith("%") && !this.getIdNo().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "id_no", this.getIdNo().substring(1));
            } else if (this.getIdNo().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "id_no", this.getIdNo().substring(0, this.getIdNo().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "id_no", this.getIdNo());
            }
        }
        if (this.getProvince() != null) {
            if (this.getProvince().startsWith("%") && this.getProvince().endsWith("%")) {
                wrapper.like(columnPrefix + "province", this.getProvince().substring(1, this.getProvince().length() - 1));
            } else if (this.getProvince().startsWith("%") && !this.getProvince().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "province", this.getProvince().substring(1));
            } else if (this.getProvince().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "province", this.getProvince().substring(0, this.getProvince().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "province", this.getProvince());
            }
        }
        if (this.getCity() != null) {
            if (this.getCity().startsWith("%") && this.getCity().endsWith("%")) {
                wrapper.like(columnPrefix + "city", this.getCity().substring(1, this.getCity().length() - 1));
            } else if (this.getCity().startsWith("%") && !this.getCity().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "city", this.getCity().substring(1));
            } else if (this.getCity().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "city", this.getCity().substring(0, this.getCity().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "city", this.getCity());
            }
        }
        if (this.getDistrict() != null) {
            if (this.getDistrict().startsWith("%") && this.getDistrict().endsWith("%")) {
                wrapper.like(columnPrefix + "district", this.getDistrict().substring(1, this.getDistrict().length() - 1));
            } else if (this.getDistrict().startsWith("%") && !this.getDistrict().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "district", this.getDistrict().substring(1));
            } else if (this.getDistrict().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "district", this.getDistrict().substring(0, this.getDistrict().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "district", this.getDistrict());
            }
        }
        if (this.getAddressDetail() != null) {
            if (this.getAddressDetail().startsWith("%") && this.getAddressDetail().endsWith("%")) {
                wrapper.like(columnPrefix + "address_detail", this.getAddressDetail().substring(1, this.getAddressDetail().length() - 1));
            } else if (this.getAddressDetail().startsWith("%") && !this.getAddressDetail().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "address_detail", this.getAddressDetail().substring(1));
            } else if (this.getAddressDetail().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "address_detail", this.getAddressDetail().substring(0, this.getAddressDetail().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "address_detail", this.getAddressDetail());
            }
        }
        if (this.getAnamnesis() != null) {
            if (this.getAnamnesis().startsWith("%") && this.getAnamnesis().endsWith("%")) {
                wrapper.like(columnPrefix + "anamnesis", this.getAnamnesis().substring(1, this.getAnamnesis().length() - 1));
            } else if (this.getAnamnesis().startsWith("%") && !this.getAnamnesis().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "anamnesis", this.getAnamnesis().substring(1));
            } else if (this.getAnamnesis().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "anamnesis", this.getAnamnesis().substring(0, this.getAnamnesis().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "anamnesis", this.getAnamnesis());
            }
        }
        if (this.getDrugAllergyHistory() != null) {
            if (this.getDrugAllergyHistory().startsWith("%") && this.getDrugAllergyHistory().endsWith("%")) {
                wrapper.like(columnPrefix + "drug_allergy_history", this.getDrugAllergyHistory().substring(1, this.getDrugAllergyHistory().length() - 1));
            } else if (this.getDrugAllergyHistory().startsWith("%") && !this.getDrugAllergyHistory().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "drug_allergy_history", this.getDrugAllergyHistory().substring(1));
            } else if (this.getDrugAllergyHistory().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "drug_allergy_history", this.getDrugAllergyHistory().substring(0, this.getDrugAllergyHistory().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "drug_allergy_history", this.getDrugAllergyHistory());
            }
        }
        if (this.getPrescriptionTime() != null) {
            if (this.getPrescriptionTime().startsWith("%") && this.getPrescriptionTime().endsWith("%")) {
                wrapper.like(columnPrefix + "prescription_time", this.getPrescriptionTime().substring(1, this.getPrescriptionTime().length() - 1));
            } else if (this.getPrescriptionTime().startsWith("%") && !this.getPrescriptionTime().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "prescription_time", this.getPrescriptionTime().substring(1));
            } else if (this.getPrescriptionTime().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "prescription_time", this.getPrescriptionTime().substring(0, this.getPrescriptionTime().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "prescription_time", this.getPrescriptionTime());
            }
        }
        if (this.getPrescriptionHospital() != null) {
            if (this.getPrescriptionHospital().startsWith("%") && this.getPrescriptionHospital().endsWith("%")) {
                wrapper.like(columnPrefix + "prescription_hospital", this.getPrescriptionHospital().substring(1, this.getPrescriptionHospital().length() - 1));
            } else if (this.getPrescriptionHospital().startsWith("%") && !this.getPrescriptionHospital().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "prescription_hospital", this.getPrescriptionHospital().substring(1));
            } else if (this.getPrescriptionHospital().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "prescription_hospital", this.getPrescriptionHospital().substring(0, this.getPrescriptionHospital().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "prescription_hospital", this.getPrescriptionHospital());
            }
        }
        if (this.getPrescriptionDepartemnt() != null) {
            if (this.getPrescriptionDepartemnt().startsWith("%") && this.getPrescriptionDepartemnt().endsWith("%")) {
                wrapper.like(columnPrefix + "prescription_departemnt", this.getPrescriptionDepartemnt().substring(1, this.getPrescriptionDepartemnt().length() - 1));
            } else if (this.getPrescriptionDepartemnt().startsWith("%") && !this.getPrescriptionDepartemnt().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "prescription_departemnt", this.getPrescriptionDepartemnt().substring(1));
            } else if (this.getPrescriptionDepartemnt().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "prescription_departemnt", this.getPrescriptionDepartemnt().substring(0, this.getPrescriptionDepartemnt().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "prescription_departemnt", this.getPrescriptionDepartemnt());
            }
        }
        if (this.getPrescriptionDoctor() != null) {
            if (this.getPrescriptionDoctor().startsWith("%") && this.getPrescriptionDoctor().endsWith("%")) {
                wrapper.like(columnPrefix + "prescription_doctor", this.getPrescriptionDoctor().substring(1, this.getPrescriptionDoctor().length() - 1));
            } else if (this.getPrescriptionDoctor().startsWith("%") && !this.getPrescriptionDoctor().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "prescription_doctor", this.getPrescriptionDoctor().substring(1));
            } else if (this.getPrescriptionDoctor().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "prescription_doctor", this.getPrescriptionDoctor().substring(0, this.getPrescriptionDoctor().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "prescription_doctor", this.getPrescriptionDoctor());
            }
        }
        if (this.getPrescriptionResult() != null) {
            if (this.getPrescriptionResult().startsWith("%") && this.getPrescriptionResult().endsWith("%")) {
                wrapper.like(columnPrefix + "prescription_result", this.getPrescriptionResult().substring(1, this.getPrescriptionResult().length() - 1));
            } else if (this.getPrescriptionResult().startsWith("%") && !this.getPrescriptionResult().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "prescription_result", this.getPrescriptionResult().substring(1));
            } else if (this.getPrescriptionResult().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "prescription_result", this.getPrescriptionResult().substring(0, this.getPrescriptionResult().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "prescription_result", this.getPrescriptionResult());
            }
        }
        if (this.getReportItem() != null) {
            if (this.getReportItem().startsWith("%") && this.getReportItem().endsWith("%")) {
                wrapper.like(columnPrefix + "report_item", this.getReportItem().substring(1, this.getReportItem().length() - 1));
            } else if (this.getReportItem().startsWith("%") && !this.getReportItem().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "report_item", this.getReportItem().substring(1));
            } else if (this.getReportItem().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "report_item", this.getReportItem().substring(0, this.getReportItem().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "report_item", this.getReportItem());
            }
        }
        if (this.getReportDesc() != null) {
            if (this.getReportDesc().startsWith("%") && this.getReportDesc().endsWith("%")) {
                wrapper.like(columnPrefix + "report_desc", this.getReportDesc().substring(1, this.getReportDesc().length() - 1));
            } else if (this.getReportDesc().startsWith("%") && !this.getReportDesc().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "report_desc", this.getReportDesc().substring(1));
            } else if (this.getReportDesc().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "report_desc", this.getReportDesc().substring(0, this.getReportDesc().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "report_desc", this.getReportDesc());
            }
        }
        if (this.getReportTime() != null) {
            if (this.getReportTime().startsWith("%") && this.getReportTime().endsWith("%")) {
                wrapper.like(columnPrefix + "report_time", this.getReportTime().substring(1, this.getReportTime().length() - 1));
            } else if (this.getReportTime().startsWith("%") && !this.getReportTime().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "report_time", this.getReportTime().substring(1));
            } else if (this.getReportTime().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "report_time", this.getReportTime().substring(0, this.getReportTime().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "report_time", this.getReportTime());
            }
        }
        if (this.getReportHospital() != null) {
            if (this.getReportHospital().startsWith("%") && this.getReportHospital().endsWith("%")) {
                wrapper.like(columnPrefix + "report_hospital", this.getReportHospital().substring(1, this.getReportHospital().length() - 1));
            } else if (this.getReportHospital().startsWith("%") && !this.getReportHospital().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "report_hospital", this.getReportHospital().substring(1));
            } else if (this.getReportHospital().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "report_hospital", this.getReportHospital().substring(0, this.getReportHospital().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "report_hospital", this.getReportHospital());
            }
        }
        if (this.getReportDoctor() != null) {
            if (this.getReportDoctor().startsWith("%") && this.getReportDoctor().endsWith("%")) {
                wrapper.like(columnPrefix + "report_doctor", this.getReportDoctor().substring(1, this.getReportDoctor().length() - 1));
            } else if (this.getReportDoctor().startsWith("%") && !this.getReportDoctor().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "report_doctor", this.getReportDoctor().substring(1));
            } else if (this.getReportDoctor().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "report_doctor", this.getReportDoctor().substring(0, this.getReportDoctor().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "report_doctor", this.getReportDoctor());
            }
        }
        if (this.getDoctorAsk() != null) {
            if (this.getDoctorAsk().startsWith("%") && this.getDoctorAsk().endsWith("%")) {
                wrapper.like(columnPrefix + "doctor_ask", this.getDoctorAsk().substring(1, this.getDoctorAsk().length() - 1));
            } else if (this.getDoctorAsk().startsWith("%") && !this.getDoctorAsk().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "doctor_ask", this.getDoctorAsk().substring(1));
            } else if (this.getDoctorAsk().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "doctor_ask", this.getDoctorAsk().substring(0, this.getDoctorAsk().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "doctor_ask", this.getDoctorAsk());
            }
        }
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
