/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：信息导入记录表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.hospital.server.base.BaseParam;
import com.xwd.hospital.server.enums.YesNoEnum;
import com.xwd.hospital.server.domain.ExcelImportInfo;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class ExcelImportInfoParam extends BaseParam<ExcelImportInfo> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 文件名称
     */
    @Parameter(description = "文件名称")
    private String fileName;
    /**
     * 导入数据类型
     */
    @Parameter(description = "导入数据类型")
    private String importType;
    /**
     * 导入状态
     */
    @Parameter(description = "导入状态")
    private YesNoEnum importState;
    /**
     * 导入状态 IN值List
     */
    @Parameter(description = "导入状态 IN值List")
    private List<String> importStateList;
    /**
     * 失败原因
     */
    @Parameter(description = "失败原因")
    private String failReason;
    /**
     * 错误所在行数
     */
    @Parameter(description = "错误所在行数")
    private Long failRow;
    /**
     * 导入时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "导入时间")
    private java.util.Date importTime;
    /**
     * 导入时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "导入时间 下限值(大于等于)")
    private java.util.Date importTimeFrom;
    /**
     * 导入时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "导入时间 上限值(小于)")
    private java.util.Date importTimeTo;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ExcelImportInfo> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ExcelImportInfo> toQueryWrapper(String columnPrefix) {
        QueryWrapper<ExcelImportInfo> wrapper = Wrappers.<ExcelImportInfo>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        if (this.getFileName() != null) {
            if (this.getFileName().startsWith("%") && this.getFileName().endsWith("%")) {
                wrapper.like(columnPrefix + "file_name", this.getFileName().substring(1, this.getFileName().length() - 1));
            } else if (this.getFileName().startsWith("%") && !this.getFileName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "file_name", this.getFileName().substring(1));
            } else if (this.getFileName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "file_name", this.getFileName().substring(0, this.getFileName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "file_name", this.getFileName());
            }
        }
        if (this.getImportType() != null) {
            if (this.getImportType().startsWith("%") && this.getImportType().endsWith("%")) {
                wrapper.like(columnPrefix + "import_type", this.getImportType().substring(1, this.getImportType().length() - 1));
            } else if (this.getImportType().startsWith("%") && !this.getImportType().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "import_type", this.getImportType().substring(1));
            } else if (this.getImportType().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "import_type", this.getImportType().substring(0, this.getImportType().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "import_type", this.getImportType());
            }
        }
        wrapper.eq(this.getImportState() != null, columnPrefix + "import_state", this.getImportState());
        wrapper.in(this.getImportStateList() != null && this.getImportStateList().size() > 0, columnPrefix + "import_state", this.getImportStateList());
        if (this.getFailReason() != null) {
            if (this.getFailReason().startsWith("%") && this.getFailReason().endsWith("%")) {
                wrapper.like(columnPrefix + "fail_reason", this.getFailReason().substring(1, this.getFailReason().length() - 1));
            } else if (this.getFailReason().startsWith("%") && !this.getFailReason().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "fail_reason", this.getFailReason().substring(1));
            } else if (this.getFailReason().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "fail_reason", this.getFailReason().substring(0, this.getFailReason().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "fail_reason", this.getFailReason());
            }
        }
        wrapper.eq(this.getFailRow() != null, columnPrefix + "fail_row", this.getFailRow());
        wrapper.eq(this.getImportTime() != null, columnPrefix + "import_time", this.getImportTime());
        wrapper.ge(this.getImportTimeFrom() != null, columnPrefix + "import_time", this.getImportTimeFrom());
        wrapper.lt(this.getImportTimeTo() != null, columnPrefix + "import_time", this.getImportTimeTo());
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
