/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：转诊记录
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.rest.req;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.swagger.v3.oas.annotations.Parameter;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import com.xwd.hospital.server.base.BaseParam;
import com.xwd.hospital.server.enums.AuditStateEnum;
import com.xwd.hospital.server.domain.ReferralRecord;

@Data
@EqualsAndHashCode(callSuper = true)
@Builder(builderMethodName = "newBuilder")
@NoArgsConstructor
@AllArgsConstructor
public class ReferralRecordParam extends BaseParam<ReferralRecord> {
    /**
     * Id
     */
    @Parameter(description = "Id")
    private Long id;
    /**
     * Id IN值List
     */
    @Parameter(description = "Id IN值List")
    private List<Long> idList;
    /**
     * 患者Id
     */
    @Parameter(description = "患者Id")
    private Long patientId;
    /**
     * 转出医院Id
     */
    @Parameter(description = "转出医院Id")
    private Long outHospitalId;
    /**
     * 转入医院Id
     */
    @Parameter(description = "转入医院Id")
    private Long inHospitalId;
    /**
     * 转出医生Id
     */
    @Parameter(description = "转出医生Id")
    private Long outDoctorId;
    /**
     * 转入医生Id
     */
    @Parameter(description = "转入医生Id")
    private Long inDoctorId;
    /**
     * 转诊医生Id
     */
    @Parameter(description = "转诊医生Id")
    private Long doctorId;
    /**
     * 审核状态
     */
    @Parameter(description = "审核状态")
    private AuditStateEnum auditState;
    /**
     * 审核状态 IN值List
     */
    @Parameter(description = "审核状态 IN值List")
    private List<String> auditStateList;
    /**
     * 失败原因
     */
    @Parameter(description = "失败原因")
    private String failReason;
    /**
     * 审核人Id
     */
    @Parameter(description = "审核人Id")
    private Long auditId;
    /**
     * 操作人Id
     */
    @Parameter(description = "操作人Id")
    private Long editorId;
    /**
     * 操作人
     */
    @Parameter(description = "操作人")
    private String editorName;
    /**
     * 创建时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间")
    private java.util.Date createTime;
    /**
     * 创建时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 下限值(大于等于)")
    private java.util.Date createTimeFrom;
    /**
     * 创建时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "创建时间 上限值(小于)")
    private java.util.Date createTimeTo;
    /**
     * 更新时间
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间")
    private java.util.Date updateTime;
    /**
     * 更新时间 下限值(大于等于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 下限值(大于等于)")
    private java.util.Date updateTimeFrom;
    /**
     * 更新时间 上限值(小于)
     */
    @DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
    @Parameter(description = "更新时间 上限值(小于)")
    private java.util.Date updateTimeTo;


    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ReferralRecord> toQueryWrapper() {
        return this.toQueryWrapper("");
    }

    /**
     * 将查询参数转化为查询Wrapper
     */
    @Override
    public QueryWrapper<ReferralRecord> toQueryWrapper(String columnPrefix) {
        QueryWrapper<ReferralRecord> wrapper = Wrappers.<ReferralRecord>query();
        wrapper.eq(this.getId() != null, columnPrefix + "id", this.getId());
        wrapper.in(this.getIdList() != null && this.getIdList().size() > 0, columnPrefix + "id", this.getIdList());
        wrapper.eq(this.getPatientId() != null, columnPrefix + "patient_id", this.getPatientId());
        wrapper.eq(this.getOutHospitalId() != null, columnPrefix + "out_hospital_id", this.getOutHospitalId());
        wrapper.eq(this.getInHospitalId() != null, columnPrefix + "in_hospital_id", this.getInHospitalId());
        wrapper.eq(this.getOutDoctorId() != null, columnPrefix + "out_doctor_id", this.getOutDoctorId());
        wrapper.eq(this.getInDoctorId() != null, columnPrefix + "in_doctor_id", this.getInDoctorId());
        wrapper.eq(this.getDoctorId() != null, columnPrefix + "doctor_id", this.getDoctorId());
        wrapper.eq(this.getAuditState() != null, columnPrefix + "audit_state", this.getAuditState());
        wrapper.in(this.getAuditStateList() != null && this.getAuditStateList().size() > 0, columnPrefix + "audit_state", this.getAuditStateList());
        if (this.getFailReason() != null) {
            if (this.getFailReason().startsWith("%") && this.getFailReason().endsWith("%")) {
                wrapper.like(columnPrefix + "fail_reason", this.getFailReason().substring(1, this.getFailReason().length() - 1));
            } else if (this.getFailReason().startsWith("%") && !this.getFailReason().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "fail_reason", this.getFailReason().substring(1));
            } else if (this.getFailReason().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "fail_reason", this.getFailReason().substring(0, this.getFailReason().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "fail_reason", this.getFailReason());
            }
        }
        wrapper.eq(this.getAuditId() != null, columnPrefix + "audit_id", this.getAuditId());
        wrapper.eq(this.getEditorId() != null, columnPrefix + "editor_id", this.getEditorId());
        if (this.getEditorName() != null) {
            if (this.getEditorName().startsWith("%") && this.getEditorName().endsWith("%")) {
                wrapper.like(columnPrefix + "editor_name", this.getEditorName().substring(1, this.getEditorName().length() - 1));
            } else if (this.getEditorName().startsWith("%") && !this.getEditorName().endsWith("%")) {
                wrapper.likeLeft(columnPrefix + "editor_name", this.getEditorName().substring(1));
            } else if (this.getEditorName().endsWith("%")) {
                wrapper.likeRight(columnPrefix + "editor_name", this.getEditorName().substring(0, this.getEditorName().length() - 1));
            } else {
                wrapper.eq(columnPrefix + "editor_name", this.getEditorName());
            }
        }
        wrapper.eq(this.getCreateTime() != null, columnPrefix + "create_time", this.getCreateTime());
        wrapper.ge(this.getCreateTimeFrom() != null, columnPrefix + "create_time", this.getCreateTimeFrom());
        wrapper.lt(this.getCreateTimeTo() != null, columnPrefix + "create_time", this.getCreateTimeTo());
        wrapper.eq(this.getUpdateTime() != null, columnPrefix + "update_time", this.getUpdateTime());
        wrapper.ge(this.getUpdateTimeFrom() != null, columnPrefix + "update_time", this.getUpdateTimeFrom());
        wrapper.lt(this.getUpdateTimeTo() != null, columnPrefix + "update_time", this.getUpdateTimeTo());
        return wrapper;
    }

}
