/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：医生工作时间配置表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.service.impl;

import java.io.Serializable;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.xwd.hospital.server.dto.DoctorTimeConfigDto;
import com.xwd.hospital.server.dto.DoctorTimeDto;
import com.xwd.hospital.server.enums.YesNoEnum;
import com.xwd.hospital.server.service.OrderService;
import jakarta.annotation.Resource;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.xwd.hospital.server.service.DoctorTimeConfigService;
import com.xwd.hospital.server.repository.DoctorTimeConfigMapper;
import com.xwd.hospital.server.repository.base.DoctorTimeConfigBaseMapper;
import com.xwd.hospital.server.domain.DoctorTimeConfig;
import com.xwd.hospital.server.rest.req.DoctorTimeConfigParam;

@Service
public class DoctorTimeConfigServiceImpl extends ServiceImpl<DoctorTimeConfigMapper, DoctorTimeConfig> implements DoctorTimeConfigService {

    @Resource
    private OrderService orderService;

    @Override
    public int updateAllFieldsById(DoctorTimeConfig entity) {
        return this.getBaseMapper().updateAllFieldsById(entity);
    }

    /**
     * 批量插入
     *
     * @param entityList ignore
     * @param batchSize  ignore
     * @return ignore
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveBatch(Collection<DoctorTimeConfig> entityList, int batchSize) {
        String sqlStatement = SqlHelper.getSqlStatement(DoctorTimeConfigBaseMapper.class, SqlMethod.INSERT_ONE);
        return executeBatch(entityList, batchSize, (sqlSession, entity) -> sqlSession.insert(sqlStatement, entity));
    }

    @Override
    public Map listDoctorTime(Long doctorId) {
        List<DoctorTimeDto> list = this.getBaseMapper().listDoctorTime(doctorId);
//        Map<String, List<DoctorTimeConfig>> collect = list.stream().collect(Collectors.groupingBy(DoctorTimeConfig::getWorkDay));
        LocalDate currentDate = LocalDate.now();

        // Format the current date to match the 'workDay' format
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        String formattedCurrentDate = currentDate.format(formatter);

        // Collect, filter, and sort the list
        Map<String, List<DoctorTimeDto>> sortedCollect = list.stream()
                .filter(config -> config.getWorkDay().compareTo(formattedCurrentDate) >= 0)
                .collect(Collectors.groupingBy(DoctorTimeDto::getWorkDay,
                        LinkedHashMap::new, // Use LinkedHashMap to maintain order
                        Collectors.toList()));
        return sortedCollect;
    }

    @Override
    @Async
    public void changeStatus(List<DoctorTimeConfigDto> list) {
        for (DoctorTimeConfigDto dto:list) {
            DoctorTimeConfig config = this.getById(dto.getId());
            if (null != config) {
                if(config.getWorkStatus() == YesNoEnum.YES && dto.getWorkStatus() == YesNoEnum.NO){
                    //查询当日是否有预约，取消预约并发送短信
                    String dateStr = config.getWorkDay() + " " + config.getWorkTime();
                    DateTime dateTime = DateUtil.parse(dateStr, DatePattern.NORM_DATETIME_MINUTE_FORMAT);
                    orderService.cancelOrderForOneDay(dateTime);
                }
                config.setWorkStatus(dto.getWorkStatus());
                this.updateById(config);
            }
        }
    }
}
