package com.xwd.hospital.server.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdcardUtil;
import cn.hutool.poi.excel.ExcelReader;
import cn.hutool.poi.excel.ExcelUtil;
import com.aspose.imaging.internal.bf.P;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.tencentcloudapi.tsf.v20180326.models.TsfPageVmGroup;
import com.xwd.hospital.server.domain.*;
import com.xwd.hospital.server.dto.ExcelDepartment;
import com.xwd.hospital.server.dto.ImportResultDto;
import com.xwd.hospital.server.dto.UserExcelDto;
import com.xwd.hospital.server.enums.*;
import com.xwd.hospital.server.rest.res.ApiCode;
import com.xwd.hospital.server.service.*;
import jakarta.annotation.Resource;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class ExcelServiceImpl implements ExcelService {
    @Resource
    private UserInfoService userInfoService;
    @Resource
    private PatientInfoService patientInfoService;
    @Resource
    private PatientPrescriptionInfoService prescriptionInfoService;
    @Resource
    private UserCaseInfoService userCaseInfoService;
    @Resource
    private UserAddressInfoService addressInfoService;
    @Resource
    private MedicalReportService medicalReportService;
    @Resource
    private DepartmentInfoService departmentInfoService;
    @Resource
    private ExcelImportInfoService excelImportInfoService;
    @Resource
    private ExcelImportInfoDetailService detailService;

    @Override
    public List<UserExcelDto> exportUserInfo() {
        //查询所有用户信息
        List<UserInfo> userInfoList = userInfoService.list();
        ArrayList<UserExcelDto> dtoList = new ArrayList<>(userInfoList.size());
        for (UserInfo userInfo : userInfoList) {
            UserExcelDto userExcelDto = new UserExcelDto();
            userExcelDto.setName(userInfo.getName());
            userExcelDto.setSex(userInfo.getSex().getName());
            userExcelDto.setPhone(userInfo.getPhoneNumber());
            userExcelDto.setIdCard(userInfo.getIdNo());
            userExcelDto.setAge(StringUtils.isEmpty(userInfo.getIdNo()) ? "" : String.valueOf(IdcardUtil.getAgeByIdCard(userInfo.getIdNo())));

            //根据userInfoId查询用户地址
            //地址记录存在多条，去最新的一条
            QueryWrapper<UserAddressInfo> userAddressInfoQueryWrapper = new QueryWrapper<>();
            userAddressInfoQueryWrapper.eq("user_info_id", userInfo.getId()).orderByDesc("create_time");
            userAddressInfoQueryWrapper.last("LIMIT 1");
            UserAddressInfo userAddressInfo = addressInfoService.getOne(userAddressInfoQueryWrapper);
            if (null == userAddressInfo) {
                userExcelDto.setProvince("");
                userExcelDto.setCity("");
                userExcelDto.setDistrict("");
                userExcelDto.setAddress("");
            } else {
                userExcelDto.setProvince(userAddressInfo.getProvince());
                userExcelDto.setCity(userAddressInfo.getCity());
                userExcelDto.setDistrict(userAddressInfo.getDistrict());
                userExcelDto.setAddress(userAddressInfo.getDetailAddress());
            }

            //根据patientId查询用户处方记录
            PatientInfo patientInfo = patientInfoService.getOne(Wrappers.<PatientInfo>query().eq("user_info_id", userInfo.getId())
                    .eq("relation", PatientRelationEnum.SELF).eq("id_no", userInfo.getIdNo()).eq("delete_status", YesNoEnum.NO));
            if (null == patientInfo) {
                userExcelDto.setPrescriptionHospital("");
                userExcelDto.setPrescriptionDepartment("");
                userExcelDto.setPrescriptionIntroduce("");
                userExcelDto.setPrescriptionTime("");
            } else {
                QueryWrapper<PatientPrescriptionInfo> patientPrescriptionInfoQueryWrapper = new QueryWrapper<>();
                patientPrescriptionInfoQueryWrapper.eq("patient_id", patientInfo.getId()).orderByDesc("create_time");
                patientPrescriptionInfoQueryWrapper.last("LIMIT 1");
                PatientPrescriptionInfo patientPrescriptionInfo = prescriptionInfoService.getOne(patientPrescriptionInfoQueryWrapper);
                if (null == patientPrescriptionInfo) {
                    userExcelDto.setPrescriptionHospital("");
                    userExcelDto.setPrescriptionDepartment("");
                    userExcelDto.setPrescriptionIntroduce("");
                    userExcelDto.setPrescriptionTime("");
                } else {
                    userExcelDto.setPrescriptionHospital(patientPrescriptionInfo.getHospitalName());
                    userExcelDto.setPrescriptionDepartment(patientPrescriptionInfo.getDepartmentName());
                    userExcelDto.setPrescriptionIntroduce(patientPrescriptionInfo.getPrescriptionIntroduce());
                    userExcelDto.setPrescriptionTime(patientPrescriptionInfo.getPrescriptionTime());
                }
            }

            //根据idNo查询报告
            QueryWrapper<MedicalReport> medicalReportQueryWrapper = new QueryWrapper<>();
            medicalReportQueryWrapper.eq("patient_id_no", userInfo.getIdNo()).orderByDesc("create_time");
            medicalReportQueryWrapper.last("LIMIT 1");
            MedicalReport medicalReport = medicalReportService.getOne(medicalReportQueryWrapper);
            if (null == medicalReport) {
                userExcelDto.setReportProject("");
                userExcelDto.setReportDesc("");
                userExcelDto.setReportTime("");
                userExcelDto.setReportHospital("");
                userExcelDto.setReportDoctor("");
                userExcelDto.setDoctorAsk("");
            } else {
                userExcelDto.setReportProject(medicalReport.getReportItem());
                userExcelDto.setReportDesc(medicalReport.getReportDeclare());
                userExcelDto.setReportTime(DateUtil.format(medicalReport.getReportTime(), "yyyy-MM-dd"));
                userExcelDto.setReportHospital(medicalReport.getReportHospital());
                userExcelDto.setReportDoctor(medicalReport.getReportDoctor());
                userExcelDto.setDoctorAsk(medicalReport.getDoctorAsks());
            }

            dtoList.add(userExcelDto);
        }
        return CollUtil.newArrayList(dtoList);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ImportResultDto importUser(List<Map<String, Object>> allData) {
        ImportResultDto importResultDto = new ImportResultDto();
        Long row = 1L;

            for (Map<String, Object> map : allData) {
                //新增患者信息
                //校验手机号码是否已经存在注册
                UserInfo userInfo = userInfoService.getOne(Wrappers.<UserInfo>query().eq("phone_number", map.get("手机号").toString())
                        .eq("delete_status", YesNoEnum.NO));
                if (null == userInfo) {
                    userInfo = new UserInfo();
                    userInfo.setUserId(0L);//关联sys_user表的id，暂时记为0
                    userInfo.setName(map.get("姓名").toString());
                    userInfo.setSex("男".equals(map.get("性别").toString()) ? SexTypeEnum.MALE : SexTypeEnum.FEMALE);
                    String idNo = map.get("证件号").toString();

                    if (!IdcardUtil.isValidCard(idNo)) {
//                        continue;
                        throw new ApiCode.ApiException(701,row.toString());
                    }

                    userInfo.setIdNo(idNo);
                    userInfo.setPhoneNumber(map.get("手机号").toString());
                    if(userInfo.getPhoneNumber().length() != 11){
                        throw new ApiCode.ApiException(702,row.toString());
                    }
                    DateTime birthday = DateUtil.parse(IdcardUtil.getBirthByIdCard(userInfo.getIdNo()));
                    userInfo.setBornDate(DateUtil.format(birthday, "yyyy-MM-dd"));
                    userInfo.setPersonalInfoFilled(YesNoEnum.NO);
                    userInfoService.save(userInfo);
                }
                //就诊人patient
                PatientInfo patientInfo = patientInfoService.getOne(Wrappers.<PatientInfo>query().eq("user_info_id", userInfo.getId())
                        .eq("relation", PatientRelationEnum.SELF).eq("id_no", userInfo.getIdNo()).eq("delete_status", YesNoEnum.NO));
                if (null == patientInfo) {
                    //同时创建自身的就诊人
                    patientInfo = new PatientInfo();
                    patientInfo.setUserInfoId(userInfo.getId());
                    patientInfo.setRelation(PatientRelationEnum.SELF);
                    patientInfo.setPatientName(userInfo.getName());
                    patientInfo.setSex(userInfo.getSex());
                    patientInfo.setIdNo(userInfo.getIdNo());
                    patientInfo.setPhoneNumber(userInfo.getPhoneNumber());
                    patientInfo.setBornDate(userInfo.getBornDate());
                    patientInfoService.save(patientInfo);
                }
                //患者地址
                String province = null == map.get("省") ? "" : map.get("省").toString();
                String city = null == map.get("市") ? "" : map.get("市").toString();
                String district = null == map.get("区") ? "" : map.get("区").toString();
                if (!StringUtils.isEmpty(province)
                        && !StringUtils.isEmpty(city)
                        && !StringUtils.isEmpty(district)) {
                    UserAddressInfo userAddressInfo = new UserAddressInfo();
                    userAddressInfo.setUserInfoId(userInfo.getId());
                    userAddressInfo.setName(userInfo.getName());
                    userAddressInfo.setPhoneNumber(userInfo.getPhoneNumber());
                    userAddressInfo.setProvince(province);
                    userAddressInfo.setCity(city);
                    userAddressInfo.setDistrict(district);
                    userAddressInfo.setDetailAddress(null == map.get("详细地址") ? "" : map.get("详细地址").toString());
                    //                addressInfos.add(userAddressInfo);
                    addressInfoService.save(userAddressInfo);

                }
                //病例信息
                String anamnesis = null == map.get("既往病史") ? "" : map.get("既往病史").toString();
                String history = null == map.get("药物过敏史") ? "" : map.get("药物过敏史").toString();
                if (!StringUtils.isEmpty(anamnesis)
                        || !StringUtils.isEmpty(history)) {
                    UserCaseInfo userCaseInfo = new UserCaseInfo();
                    userCaseInfo.setUserInfoId(userInfo.getId());
                    userCaseInfo.setName(userInfo.getName());
                    userCaseInfo.setPhoneNumber(userInfo.getPhoneNumber());
                    userCaseInfo.setAnamnesis(anamnesis);
                    userCaseInfo.setDrugAllergyHistory(history);
                    //                userCaseInfos.add(userCaseInfo);
                    userCaseInfoService.save(userCaseInfo);
                }
                //处方信息
                String hospital = null == map.get("处方医院") ? "" : map.get("处方医院").toString();
                String department = null == map.get("处方科室") ? "" : map.get("处方科室").toString();
                String time = null == map.get("处方时间") ? "" : map.get("处方时间").toString();
                String result = null == map.get("处方结果") ? "" : map.get("处方结果").toString();
                if (!StringUtils.isEmpty(hospital)
                        && !StringUtils.isEmpty(department)
                        && !StringUtils.isEmpty(time)
                        && !StringUtils.isEmpty(result)) {
                    PatientPrescriptionInfo patientPrescriptionInfo = new PatientPrescriptionInfo();
                    patientPrescriptionInfo.setPatientId(patientInfo.getId());
                    patientPrescriptionInfo.setHospitalName(hospital);
                    patientPrescriptionInfo.setDepartmentName(department);
                    patientPrescriptionInfo.setPrescriptionTime(time);
                    patientPrescriptionInfo.setPrescriptionIntroduce(result);
                    //                prescriptionInfos.add(patientPrescriptionInfo);
                    prescriptionInfoService.save(patientPrescriptionInfo);
                }
                //报告信息
                MedicalReport medicalReport = new MedicalReport();
                medicalReport.setAge(Integer.valueOf(null == map.get("年龄") ? "" : map.get("年龄").toString()));
                medicalReport.setPatientName(null == map.get("姓名") ? "" : map.get("姓名").toString());
                medicalReport.setReportDoctor(null == map.get("报告医生") ? "" : map.get("报告医生").toString());
                medicalReport.setReportHospital(null == map.get("报告医院") ? "" : map.get("报告医院").toString());
                medicalReport.setPatientIdNo(null == map.get("证件号") ? "" : map.get("证件号").toString());
                medicalReport.setSex("男".equals(null == map.get("性别") ? SexTypeEnum.MALE : map.get("性别").toString()) ? SexTypeEnum.MALE : SexTypeEnum.FEMALE);
                medicalReport.setReportItem(null == map.get("报告项目") ? "" : map.get("报告项目").toString());
                medicalReport.setReportDeclare(null == map.get("报告描述") ? "" : map.get("报告描述").toString());
                medicalReport.setReportTime(null == map.get("报告时间") ? new Date() : DateUtil.parse(map.get("报告时间").toString()));
                medicalReport.setReportType(ReportTypeEnum.CT);
                medicalReport.setDoctorAsks(null == map.get("医生医嘱") ? "" : map.get("医生医嘱").toString());
                //            medicalReports.add(medicalReport);
                medicalReportService.save(medicalReport);


                row++;
            }
//        }catch (Exception e){
//            importResultDto.setResult(false);
//            importResultDto.setRow(row);
//            importResultDto.setReason("导入失败");
//            return importResultDto;
//        }
        importResultDto.setRow(row);
        importResultDto.setResult(true);
        return importResultDto;
    }

    @Override
    public boolean importDepartments(MultipartFile multipartFile) throws Exception {
        File file = convertMultipartFileToFile(multipartFile);
        ExcelReader reader = ExcelUtil.getReader(file, "Sheet1");

        List<Map<String, Object>> allData = reader.readAll();
        //将 allData 转换为 ExcelDepartment 的list
        List<ExcelDepartment> excelDepartmentList = allData.stream().map(map -> {
            ExcelDepartment excelDepartment = new ExcelDepartment();
            excelDepartment.setDepartmentName(map.get("科室名称").toString());
            excelDepartment.setDepartmentIntroduce(null == map.get("科室描述") ? "" : map.get("科室描述").toString());
            //excel中临时序号
            excelDepartment.setExcelId(Long.parseLong(map.get("序号").toString()));
            excelDepartment.setExcelParentId(Long.parseLong(map.get("上级科室序号").toString()));
            return excelDepartment;
        }).collect(Collectors.toList());

        // 使用Collectors.groupingBy进行分组
        Map<Long, List<ExcelDepartment>> excelDepartmentGroups = excelDepartmentList.stream()
                .collect(Collectors.groupingBy(ExcelDepartment::getExcelParentId));

        // 获取一级部门列表
        List<ExcelDepartment> topLevelDepartments = excelDepartmentGroups.get(0L);

        topLevelDepartments.forEach(excelDepartment -> {
            DepartmentInfo departmentInfo = new DepartmentInfo();
            departmentInfo.setDepartmentName(excelDepartment.getDepartmentName());
            departmentInfo.setDepartmentIntroduce(excelDepartment.getDepartmentIntroduce());
            departmentInfo.setDepartmentLevel(DepartmentLevelEnum.FIRST_LEVEL);
            departmentInfo.setParentId(0L);
            departmentInfoService.save(departmentInfo);
            //插入所有一级科室数据，同时返回记录数据库中的id
            excelDepartment.setId(departmentInfo.getId());
            //根据excelParentId获取当前一级科室下所有的科室
            List<ExcelDepartment> secondeDepartmentList = excelDepartmentGroups.get(excelDepartment.getExcelId());
            secondeDepartmentList.forEach(secondeDepartment -> {
                DepartmentInfo secondeDepartmentInfo = new DepartmentInfo();
                secondeDepartmentInfo.setDepartmentName(secondeDepartment.getDepartmentName());
                secondeDepartmentInfo.setDepartmentIntroduce(secondeDepartment.getDepartmentIntroduce());
                secondeDepartmentInfo.setDepartmentLevel(DepartmentLevelEnum.SECOND_LEVEL);
                secondeDepartmentInfo.setParentId(departmentInfo.getId());
                departmentInfoService.save(secondeDepartmentInfo);
            });
        });

        return true;
    }
    public File convertMultipartFileToFile(MultipartFile multipartFile) throws IOException {
        File file = new File(multipartFile.getOriginalFilename());
        FileUtils.writeByteArrayToFile(file, multipartFile.getBytes());
        return file;
    }

}
