/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：家庭医生
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.service.impl;

import java.io.Serializable;
import java.util.List;
import java.util.ArrayList;
import java.util.Collection;

import com.xwd.hospital.server.domain.User;
import com.xwd.hospital.server.enums.FamilyDoctorStateEnum;
import com.xwd.hospital.server.rest.res.ApiCode;
import jakarta.annotation.Resource;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.xwd.hospital.server.service.FamilyDoctorService;
import com.xwd.hospital.server.repository.FamilyDoctorMapper;
import com.xwd.hospital.server.repository.base.FamilyDoctorBaseMapper;
import com.xwd.hospital.server.domain.FamilyDoctor;
import com.xwd.hospital.server.rest.req.FamilyDoctorParam;

@Service
public class FamilyDoctorServiceImpl extends ServiceImpl<FamilyDoctorMapper, FamilyDoctor> implements FamilyDoctorService {

    @Override
    public int updateAllFieldsById(FamilyDoctor entity) {
        return this.getBaseMapper().updateAllFieldsById(entity);
    }

    /**
     * 批量插入
     *
     * @param entityList ignore
     * @param batchSize  ignore
     * @return ignore
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveBatch(Collection<FamilyDoctor> entityList, int batchSize) {
        String sqlStatement = SqlHelper.getSqlStatement(FamilyDoctorBaseMapper.class, SqlMethod.INSERT_ONE);
        return executeBatch(entityList, batchSize, (sqlSession, entity) -> sqlSession.insert(sqlStatement, entity));
    }

    @Override
    public boolean confirm(Long id,User user) {
        FamilyDoctor record = this.getById(id);
        if (null == record){
            throw new ApiCode.ApiException(-1,"数据不存在");
        }else {
            if(record.getAuditState() != FamilyDoctorStateEnum.TO_CONFIRM){
                throw new ApiCode.ApiException(-1,"数据状态不正确");
            }
            record.setAuditState(FamilyDoctorStateEnum.TO_AUDIT);
            this.updateById(record);
        }
        return false;
    }
    @Override
    public boolean reject(Long id, String rejectReason,User user) {
        FamilyDoctor record = this.getById(id);
        if (null == record){
            throw new ApiCode.ApiException(-1,"数据不存在");
        }else {
            if(record.getAuditState() != FamilyDoctorStateEnum.TO_CONFIRM){
                throw new ApiCode.ApiException(-1,"数据状态不正确");
            }
            record.setAuditState(FamilyDoctorStateEnum.REJECT);
            record.setRejectReason(rejectReason);
            this.updateById(record);
        }
        return false;
    }

    @Override
    public boolean auditPass(Long id,User user) {
        FamilyDoctor record = this.getById(id);
        if (null == record){
            throw new ApiCode.ApiException(-1,"数据不存在");
        }else {
            if(record.getAuditState() != FamilyDoctorStateEnum.TO_AUDIT){
                throw new ApiCode.ApiException(-1,"数据状态不正确");
            }
            record.setAuditState(FamilyDoctorStateEnum.AUDIT_SUCCESS);
            record.setAuditId(user.getId());
            this.updateById(record);
        }
        return false;
    }
    @Override
    public boolean auditFail(Long id, String rejectReason,User user) {
        FamilyDoctor record = this.getById(id);
        if (null == record){
            throw new ApiCode.ApiException(-1,"数据不存在");
        }else {
            if(record.getAuditState() != FamilyDoctorStateEnum.TO_AUDIT){
                throw new ApiCode.ApiException(-1,"数据状态不正确");
            }
            record.setAuditState(FamilyDoctorStateEnum.AUDIT_FAIL);
            record.setRejectReason(rejectReason);
            record.setAuditId(user.getId());
            this.updateById(record);
        }
        return false;
    }
}
