package com.xwd.hospital.server.task;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xwd.hospital.server.domain.Order;
import com.xwd.hospital.server.domain.UserCouponInfo;
import com.xwd.hospital.server.enums.CouponUseStateEnum;
import com.xwd.hospital.server.enums.OrderStateEnum;
import com.xwd.hospital.server.enums.YesNoEnum;
import com.xwd.hospital.server.service.OrderService;
import com.xwd.hospital.server.service.SmsService;
import com.xwd.hospital.server.service.UserCouponInfoService;
import com.xwd.hospital.server.service.impl.DelayQueueService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

@Component
@Async
@Slf4j
public class OrderTask {
    @Resource
    private DelayQueueService delayQueueService;
    @Resource
    private OrderService orderService;
    @Resource
    private SmsService smsService;

    /**
     * 每秒钟清理一次未支付订单
     */
    @Scheduled(cron = "* * * * * *")
    public void cancelUnpayOrder(){

        delayQueueService.pollAndProcessDelayedMessages();

    }

    /**
     * 每半小时发送患者短信提醒
     */
    @Scheduled(cron = "0 0/30 * * * ? ")
    public void patientRemind(){

        Date now = new Date();
        Date dateTime = DateUtil.offsetMinute(now, 30);

        log.info("发送患者提醒短信中。。。。。。。。");
        new Thread(() -> {
            List<Order> orderList = orderService.list(Wrappers.<Order>query()
                    .eq("delete_status", YesNoEnum.NO.toString())
                    .eq("appointment_date", dateTime)
                    .eq("order_state", OrderStateEnum.IN_SERVICE.toString()));
            for (Order order : orderList) {
                //发送短信
                smsService.sendPatientRemind(order.getPatientPhoneNumber(),order.getOrderType().getName());
            }
        }).start();


    }

    /**
     * 每天早上8点发送今日短信提醒
     */
    @Scheduled(cron = "0 0 8 * * ? ")
    public void doctorRemind(){

        log.info("发送医生提醒短信中。。。。。。。。");
        new Thread(() -> {
            orderService.selectCountForSms().forEach(smsOrderCountDto -> {
                //发送短信
                smsService.sendDoctorRemind(smsOrderCountDto.getPhoneNumber(),String.valueOf(smsOrderCountDto.getOrderCount()));
            });
        }).start();


    }
}
