package com.xwd.hospital.server.task;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xwd.hospital.server.domain.DoctorInfo;
import com.xwd.hospital.server.domain.DoctorTimeConfig;
import com.xwd.hospital.server.domain.Order;
import com.xwd.hospital.server.enums.OrderStateEnum;
import com.xwd.hospital.server.enums.YesNoEnum;
import com.xwd.hospital.server.service.*;
import com.xwd.hospital.server.service.impl.DelayQueueService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Component
@Async
@Slf4j
public class WorkTimeTask {
    @Resource
    private DoctorTimeConfigService doctorTimeConfigService;
    @Resource
    private DoctorInfoService doctorInfoService;

    //24小时，每半小时一个节点，48个节点放入list中
    private static final List<String> workTimeList = Arrays.asList(
            "06:00","06:30","07:00","07:30",
            "08:00","08:30","09:00","09:30","10:00","10:30","11:00","11:30",
            "12:00","12:30","13:00","13:30","14:00","14:30","15:00","15:30",
            "16:00","16:30","17:00","17:30","18:00","18:30","19:00","19:30",
            "20:00","20:30","21:00","21:30"
    );


    /**
     * 每天23：55分生成
     */
    @Scheduled(cron = "0 55 23 * * ? ")
    public void createWorkTime(){
        log.info("生成医生排班中。。。。。。。。");
        Date now = new Date();
        Date dateTime = DateUtil.offsetDay(now, 14);
        List<DoctorInfo> doctorList = doctorInfoService.list();
        for (DoctorInfo doctorInfo:doctorList) {
            createWorkTime(doctorInfo.getId(),dateTime);
        }
        log.info("生成医生排班完成。。。。。。。。");
    }

    void createWorkTime(Long doctorId,Date dateTime){
        ArrayList<DoctorTimeConfig> serviceList = new ArrayList<>(14*48);
        for (String time:workTimeList) {
            DoctorTimeConfig config = new DoctorTimeConfig();
            config.setDoctorId(doctorId);
            config.setWorkDay(DateUtil.format(dateTime,"yyyy-MM-dd"));
            config.setWorkTime(time);
            serviceList.add(config);
        }
        doctorTimeConfigService.saveBatch(serviceList);
    }
}
